@@ -36,7 +36,11 @@ struct glistener {
   void (*evaluator)(glistener *g, const char *text);
   void (*completer)(glistener *g, bool (*symbol_func)(const char *symbol_name, void *data), void *data);
   void (*colorizer)(glistener *g, glistener_colorizer_t type, int start, int end);
+#if (GTK_CHECK_VERSION(3, 92, 1))
+  bool (*keyer)(glistener *g, GtkWidget *w, GdkEvent *e);
+#else
   bool (*keyer)(glistener *g, GtkWidget *w, GdkEventKey *e);
+#endif
 };
 
 #if ((!GTK_CHECK_VERSION(3, 0, 0))) && (!defined(GDK_KEY_Return))
@@ -66,7 +70,7 @@ struct glistener {
   #define GDK_KEY_y         GDK_y
 #endif 
 
-#if GTK_CHECK_VERSION(3, 92, 1)
+#if (GTK_CHECK_VERSION(3, 92, 1))
 static guint EVENT_KEYVAL(GdkEvent *e)
 {
   guint val = 0;
@@ -79,12 +83,6 @@ static guint EVENT_KEYVAL(GdkEvent *e)
   #define EVENT_KEYVAL(Ev) (Ev)->keyval
 #endif
 
-#if (GTK_CHECK_VERSION(3, 0, 0) && defined(__GNUC__) && (!(defined(__cplusplus))))
-  #define EVENT_STATE(Ev) ({ GdkModifierType Type;  gdk_event_get_state((GdkEvent *)Ev, &Type); Type; })
-#else
-  #define EVENT_STATE(Ev) (Ev)->state
-#endif
-
 #define ControlMask GDK_CONTROL_MASK
 #define MetaMask GDK_MOD1_MASK
 
@@ -159,13 +157,20 @@ void glistener_set_colorizer(glistener *g, void (*colorizer)(glistener *g, glist
   else g->colorizer = default_colorizer;
 }
 
-
+#if (GTK_CHECK_VERSION(3, 92, 1))
+static bool default_keyer(glistener *g, GtkWidget *w, GdkEvent *e)
+#else
 static bool default_keyer(glistener *g, GtkWidget *w, GdkEventKey *e)
+#endif
 {
   return(false);
 }
 
+#if (GTK_CHECK_VERSION(3, 92, 1))
+void glistener_set_keyer(glistener *g, bool (*key)(glistener *g, GtkWidget *w, GdkEvent *e))
+#else
 void glistener_set_keyer(glistener *g, bool (*key)(glistener *g, GtkWidget *w, GdkEventKey *e))
+#endif
 {
   if (key)
     g->keyer = key;
@@ -657,7 +662,7 @@ void glistener_clear(glistener *g)
 
 bool glistener_write(glistener *g, FILE *fp)
 {
-  char *str = NULL;
+  char *str;
   GtkTextIter start, end;
 
   gtk_text_buffer_get_start_iter(g->buffer, &start);
@@ -1527,8 +1532,11 @@ void glistener_key_bindings(glistener *g, gpointer cls)
 static void glistener_return_callback(glistener *g);
 static void glistener_completion(glistener *g, int end);
 
-
+#if (GTK_CHECK_VERSION(3, 92, 1))
+static gboolean glistener_key_press(GtkWidget *w, GdkEvent *event, gpointer data)
+#else
 static gboolean glistener_key_press(GtkWidget *w, GdkEventKey *event, gpointer data)
+#endif
 {
   glistener *g = (glistener *)data;
 
@@ -1539,7 +1547,11 @@ static gboolean glistener_key_press(GtkWidget *w, GdkEventKey *event, gpointer d
       GdkModifierType state;
 
       key = EVENT_KEYVAL(event);
-      state = (GdkModifierType)EVENT_STATE(event);
+#if (GTK_CHECK_VERSION(3, 0, 0))
+      gdk_event_get_state((GdkEvent *)event, &state);
+#else
+      state = (GdkModifierType)(event->state);
+#endif
       
       /* fprintf(stderr, "key: %d, state: %x\n", key, state); */
       
@@ -1807,8 +1819,14 @@ static void check_for_empty_listener(GtkTextView *w, gpointer data)
 static gboolean glistener_button_release(GtkWidget *w, GdkEventButton *ev, gpointer data)
 {
   glistener *g = (glistener *)data;
+  GdkModifierType state;
 
-  if (EVENT_STATE(ev) & GDK_BUTTON2_MASK)
+#if (GTK_CHECK_VERSION(3, 0, 0))
+  gdk_event_get_state((GdkEvent *)ev, &state);
+#else
+  state = (GdkModifierType)(ev->state);
+#endif
+  if (state & GDK_BUTTON2_MASK)
     glistener_set_cursor_position(g, g->insertion_position);
   else
     {
@@ -1833,8 +1851,6 @@ static gboolean glistener_button_release(GtkWidget *w, GdkEventButton *ev, gpoin
 
 
 
-
-
 /* ---------------- <cr> evaluation ---------------- */
 
 static void eval_text(glistener *g, GtkTextIter *start, GtkTextIter *end)
@@ -2892,6 +2908,8 @@ glistener *glistener_new(GtkWidget *parent, void (*initializations)(glistener *g
 }
 
 /* changes:
+ * 31-Mar-18: gtk 4 support.
+ * --------
  * 31-Jul-17: added access to text and buffer.
  * --------
  * 19-Mar-15: changed strcopy macro.
