@@ -1,8 +1,8 @@
 #ifndef S7_H
 #define S7_H
 
-#define S7_VERSION "5.16"
-#define S7_DATE "17-Mar-18"
+#define S7_VERSION "6.0"
+#define S7_DATE "23-Mar-18"
 
 #include <stdint.h>           /* for int64_t */
 
@@ -51,7 +51,7 @@ bool s7_is_null(s7_scheme *sc, s7_pointer p);                        /* null? */
    */
 
 bool s7_is_valid(s7_scheme *sc, s7_pointer arg);                     /* does 'arg' look like an s7 object? */
-bool s7_is_c_pointer(s7_pointer arg);
+bool s7_is_c_pointer(s7_pointer arg);                                /* (c-pointer? arg) */
 bool s7_is_c_pointer_of_type(s7_pointer arg, s7_pointer type);
 void *s7_c_pointer(s7_pointer p);
 s7_pointer s7_c_pointer_type(s7_pointer p);
@@ -88,9 +88,9 @@ bool s7_is_provided(s7_scheme *sc, const char *feature);             /* (provide
 
 
 s7_pointer s7_error(s7_scheme *sc, s7_pointer type, s7_pointer info);
-s7_pointer s7_wrong_type_arg_error(s7_scheme *sc, const char *caller, int32_t arg_n, s7_pointer arg, const char *descr);
+s7_pointer s7_wrong_type_arg_error(s7_scheme *sc, const char *caller, s7_int arg_n, s7_pointer arg, const char *descr);
   /* set arg_n to 0 to indicate that caller takes only one argument (so the argument number need not be reported */
-s7_pointer s7_out_of_range_error(s7_scheme *sc, const char *caller, int32_t arg_n, s7_pointer arg, const char *descr);
+s7_pointer s7_out_of_range_error(s7_scheme *sc, const char *caller, s7_int arg_n, s7_pointer arg, const char *descr);
 s7_pointer s7_wrong_number_of_args_error(s7_scheme *sc, const char *caller, s7_pointer args);
 
   /* these are equivalent to (error ...) in Scheme
@@ -118,16 +118,14 @@ s7_pointer s7_stacktrace(s7_scheme *sc);
 s7_pointer s7_history(s7_scheme *sc);                                /* the current (circular backwards) history buffer */
 s7_pointer s7_add_to_history(s7_scheme *sc, s7_pointer entry);       /* add entry to the history buffer */
 
-uint32_t s7_gc_protect(s7_scheme *sc, s7_pointer x);
+s7_int s7_gc_protect(s7_scheme *sc, s7_pointer x);
 void s7_gc_unprotect(s7_scheme *sc, s7_pointer x);
-void s7_gc_unprotect_at(s7_scheme *sc, uint32_t loc);
-s7_pointer s7_gc_protected_at(s7_scheme *sc, uint32_t loc);
+void s7_gc_unprotect_at(s7_scheme *sc, s7_int loc);
+s7_pointer s7_gc_protected_at(s7_scheme *sc, s7_int loc);
 s7_pointer s7_gc_protect_via_stack(s7_scheme *sc, s7_pointer x);
 
-s7_pointer s7_gc_on(s7_scheme *sc, bool on);
-void s7_gc_stats(s7_scheme *sc, bool on);
-int64_t s7_heap_size(s7_scheme *sc);
-int64_t s7_gc_freed(s7_scheme *sc);
+s7_pointer s7_gc_on(s7_scheme *sc, bool on);                         /* (gc on) */
+void s7_gc_stats(s7_scheme *sc, bool on);                            /* (*s7* 'gc-stats) */
 
   /* any s7_pointer object held in C (as a local variable for example) needs to be
    *   protected from garbage collection if there is any chance the GC may run without
@@ -211,12 +209,12 @@ s7_pointer s7_cddaar(s7_pointer p);
 
 bool s7_is_list(s7_scheme *sc, s7_pointer p);                                /* (list? p) -> (or (pair? p) (null? p)) */
 bool s7_is_proper_list(s7_scheme *sc, s7_pointer p);                         /* (proper-list? p) */
-int32_t s7_list_length(s7_scheme *sc, s7_pointer a);                         /* (length a) */
-s7_pointer s7_list(s7_scheme *sc, int32_t num_values, ...);                  /* (list ...) */
+s7_int s7_list_length(s7_scheme *sc, s7_pointer a);                          /* (length a) */
+s7_pointer s7_list(s7_scheme *sc, s7_int num_values, ...);                   /* (list ...) */
 s7_pointer s7_reverse(s7_scheme *sc, s7_pointer a);                          /* (reverse a) */
 s7_pointer s7_append(s7_scheme *sc, s7_pointer a, s7_pointer b);             /* (append a b) */
-s7_pointer s7_list_ref(s7_scheme *sc, s7_pointer lst, int32_t num);          /* (list-ref lst num) */
-s7_pointer s7_list_set(s7_scheme *sc, s7_pointer lst, int32_t num, s7_pointer val); /* (list-set! lst num val) */
+s7_pointer s7_list_ref(s7_scheme *sc, s7_pointer lst, s7_int num);           /* (list-ref lst num) */
+s7_pointer s7_list_set(s7_scheme *sc, s7_pointer lst, s7_int num, s7_pointer val); /* (list-set! lst num val) */
 s7_pointer s7_assoc(s7_scheme *sc, s7_pointer obj, s7_pointer lst);          /* (assoc obj lst) */
 s7_pointer s7_assq(s7_scheme *sc, s7_pointer obj, s7_pointer x);             /* (assq obj lst) */
 s7_pointer s7_member(s7_scheme *sc, s7_pointer obj, s7_pointer lst);         /* (member obj lst) */
@@ -226,21 +224,21 @@ bool s7_tree_memq(s7_scheme *sc, s7_pointer sym, s7_pointer tree);           /*
 bool s7_is_string(s7_pointer p);                                             /* (string? p) */
 const char *s7_string(s7_pointer p);                                         /* Scheme string -> C string (do not free the string) */
 s7_pointer s7_make_string(s7_scheme *sc, const char *str);                   /* C string -> Scheme string (str is copied) */
-s7_pointer s7_make_string_with_length(s7_scheme *sc, const char *str, int32_t len);  /* same as s7_make_string, but provides strlen */
+s7_pointer s7_make_string_with_length(s7_scheme *sc, const char *str, s7_int len);  /* same as s7_make_string, but provides strlen */
 s7_pointer s7_make_string_wrapper(s7_scheme *sc, const char *str);
 s7_pointer s7_make_permanent_string(const char *str);                        /* make a string that will never be GC'd */
-uint32_t s7_string_length(s7_pointer str);                                   /* (string-length str) */
+s7_int s7_string_length(s7_pointer str);                                   /* (string-length str) */
 
 
 bool s7_is_character(s7_pointer p);                                          /* (character? p) */
-char s7_character(s7_pointer p);                                             /* Scheme character -> C char */
-s7_pointer s7_make_character(s7_scheme *sc, uint32_t c);                     /* C char (as uint32_t) -> Scheme character */
+uint8_t s7_character(s7_pointer p);                                          /* Scheme character -> unsigned C char */
+s7_pointer s7_make_character(s7_scheme *sc, uint8_t c);                      /* unsigned C char -> Scheme character */
 
 
 bool s7_is_number(s7_pointer p);                                             /* (number? p) */
 bool s7_is_integer(s7_pointer p);                                            /* (integer? p) */
-s7_int s7_integer(s7_pointer p);                                             /* Scheme integer -> C integer (int64_t) */
-s7_pointer s7_make_integer(s7_scheme *sc, s7_int num);                       /* C int64_t -> Scheme integer */
+s7_int s7_integer(s7_pointer p);                                             /* Scheme integer -> C integer (s7_int) */
+s7_pointer s7_make_integer(s7_scheme *sc, s7_int num);                       /* C s7_int -> Scheme integer */
 
 bool s7_is_real(s7_pointer p);                                               /* (real? p) */
 s7_double s7_real(s7_pointer p);                                             /* Scheme real -> C double */
@@ -266,7 +264,7 @@ bool s7_is_complex(s7_pointer arg);                                         /* (
 s7_pointer s7_make_complex(s7_scheme *sc, s7_double a, s7_double b);        /* returns the Scheme object a+bi */
 s7_double s7_real_part(s7_pointer z);                                       /* (real-part z) */
 s7_double s7_imag_part(s7_pointer z);                                       /* (imag-part z) */
-char *s7_number_to_string(s7_scheme *sc, s7_pointer obj, int32_t radix);    /* (number->string obj radix) */
+char *s7_number_to_string(s7_scheme *sc, s7_pointer obj, s7_int radix);     /* (number->string obj radix) */
 
 bool s7_is_vector(s7_pointer p);                                            /* (vector? p) */
 s7_int s7_vector_length(s7_pointer vec);                                    /* (vector-length vec) */
@@ -281,13 +279,13 @@ bool s7_is_int_vector(s7_pointer p);                                        /* (
 
 s7_pointer s7_vector_ref(s7_scheme *sc, s7_pointer vec, s7_int index);                            /* (vector-ref vec index) */
 s7_pointer s7_vector_set(s7_scheme *sc, s7_pointer vec, s7_int index, s7_pointer a);              /* (vector-set! vec index a) */
-s7_pointer s7_vector_ref_n(s7_scheme *sc, s7_pointer vector, int32_t indices, ...);                   /* multidimensional vector-ref */
-s7_pointer s7_vector_set_n(s7_scheme *sc, s7_pointer vector, s7_pointer value, int32_t indices, ...); /* multidimensional vector-set! */
+s7_pointer s7_vector_ref_n(s7_scheme *sc, s7_pointer vector, s7_int indices, ...);                   /* multidimensional vector-ref */
+s7_pointer s7_vector_set_n(s7_scheme *sc, s7_pointer vector, s7_pointer value, s7_int indices, ...); /* multidimensional vector-set! */
 
 s7_pointer s7_make_vector(s7_scheme *sc, s7_int len);                                 /* (make-vector len) */
-s7_pointer s7_make_int_vector(s7_scheme *sc, s7_int len, int32_t dims, s7_int *dim_info);
-s7_pointer s7_make_float_vector(s7_scheme *sc, s7_int len, int32_t dims, s7_int *dim_info);
-s7_pointer s7_make_float_vector_wrapper(s7_scheme *sc, s7_int len, s7_double *data, int32_t dims, s7_int *dim_info, bool free_data);
+s7_pointer s7_make_int_vector(s7_scheme *sc, s7_int len, s7_int dims, s7_int *dim_info);
+s7_pointer s7_make_float_vector(s7_scheme *sc, s7_int len, s7_int dims, s7_int *dim_info);
+s7_pointer s7_make_float_vector_wrapper(s7_scheme *sc, s7_int len, s7_double *data, s7_int dims, s7_int *dim_info, bool free_data);
 s7_pointer s7_make_and_fill_vector(s7_scheme *sc, s7_int len, s7_pointer fill);       /* (make-vector len fill) */
 
 void s7_vector_fill(s7_scheme *sc, s7_pointer vec, s7_pointer obj);                   /* (vector-fill! vec obj) */
@@ -322,7 +320,7 @@ s7_pointer s7_hook_set_functions(s7_scheme *sc, s7_pointer hook, s7_pointer func
 bool s7_is_input_port(s7_scheme *sc, s7_pointer p);                         /* (input-port? p) */
 bool s7_is_output_port(s7_scheme *sc, s7_pointer p);                        /* (output-port? p) */
 const char *s7_port_filename(s7_pointer x);                                 /* (port-filename p) */
-int32_t s7_port_line_number(s7_pointer p);                                  /* (port-line-number p) */
+s7_int s7_port_line_number(s7_pointer p);                                   /* (port-line-number p) */
 
 s7_pointer s7_current_input_port(s7_scheme *sc);                            /* (current-input-port) */
 s7_pointer s7_set_current_input_port(s7_scheme *sc, s7_pointer p);          /* (set-current-input-port) */
@@ -345,16 +343,16 @@ const char *s7_get_output_string(s7_scheme *sc, s7_pointer out_port);       /* (
 void s7_flush_output_port(s7_scheme *sc, s7_pointer p);                     /* (flush-output-port port) */
 
 typedef enum {S7_READ, S7_READ_CHAR, S7_READ_LINE, S7_READ_BYTE, S7_PEEK_CHAR, S7_IS_CHAR_READY} s7_read_t;
-s7_pointer s7_open_output_function(s7_scheme *sc, void (*function)(s7_scheme *sc, unsigned char c, s7_pointer port));  
+s7_pointer s7_open_output_function(s7_scheme *sc, void (*function)(s7_scheme *sc, uint8_t c, s7_pointer port));  
 s7_pointer s7_open_input_function(s7_scheme *sc, s7_pointer (*function)(s7_scheme *sc, s7_read_t read_choice, s7_pointer port));
 
-int32_t s7_read_char(s7_scheme *sc, s7_pointer port);                       /* (read-char port) */
-int32_t s7_peek_char(s7_scheme *sc, s7_pointer port);                       /* (peek-char port) */
+s7_pointer s7_read_char(s7_scheme *sc, s7_pointer port);                    /* (read-char port) */
+s7_pointer s7_peek_char(s7_scheme *sc, s7_pointer port);                    /* (peek-char port) */
 s7_pointer s7_read(s7_scheme *sc, s7_pointer port);                         /* (read port) */
 void s7_newline(s7_scheme *sc, s7_pointer port);                            /* (newline port) */
-void s7_write_char(s7_scheme *sc, int32_t c, s7_pointer port);                  /* (write-char c port) */
-void s7_write(s7_scheme *sc, s7_pointer obj, s7_pointer port);              /* (write obj port) */
-void s7_display(s7_scheme *sc, s7_pointer obj, s7_pointer port);            /* (display obj port) */
+s7_pointer s7_write_char(s7_scheme *sc, s7_pointer c, s7_pointer port);     /* (write-char c port) */
+s7_pointer s7_write(s7_scheme *sc, s7_pointer obj, s7_pointer port);        /* (write obj port) */
+s7_pointer s7_display(s7_scheme *sc, s7_pointer obj, s7_pointer port);      /* (display obj port) */
 const char *s7_format(s7_scheme *sc, s7_pointer args);                      /* (format ... */
 
 
@@ -449,7 +447,7 @@ s7_pointer s7_closure_body(s7_scheme *sc, s7_pointer p);
 s7_pointer s7_closure_let(s7_scheme *sc, s7_pointer p);
 s7_pointer s7_closure_args(s7_scheme *sc, s7_pointer p);
 s7_pointer s7_funclet(s7_scheme *sc, s7_pointer p);                         /* (funclet x) */
-bool s7_is_aritable(s7_scheme *sc, s7_pointer x, int32_t args);             /* (aritable? x args) */
+bool s7_is_aritable(s7_scheme *sc, s7_pointer x, s7_int args);              /* (aritable? x args) */
 s7_pointer s7_arity(s7_scheme *sc, s7_pointer x);                           /* (arity x) */
 const char *s7_help(s7_scheme *sc, s7_pointer obj);                         /* (help obj) */
 s7_pointer s7_make_continuation(s7_scheme *sc);                             /* call/cc... (see example below) */
@@ -458,21 +456,21 @@ const char *s7_documentation(s7_scheme *sc, s7_pointer p);                  /* (
 s7_pointer s7_setter(s7_scheme *sc, s7_pointer obj);                        /* (setter obj) */
 s7_pointer s7_set_setter(s7_scheme *sc, s7_pointer p, s7_pointer setter);   /* (set! (setter p) setter) */
 s7_pointer s7_signature(s7_scheme *sc, s7_pointer func);                    /* (signature obj) */
-s7_pointer s7_make_signature(s7_scheme *sc, int32_t len, ...);              /* procedure-signature data */
-s7_pointer s7_make_circular_signature(s7_scheme *sc, int32_t cycle_point, int32_t len, ...);
+s7_pointer s7_make_signature(s7_scheme *sc, s7_int len, ...);               /* procedure-signature data */
+s7_pointer s7_make_circular_signature(s7_scheme *sc, s7_int cycle_point, s7_int len, ...);
 
-s7_pointer s7_make_function(s7_scheme *sc, const char *name, s7_function fnc, int32_t required_args, int32_t optional_args, bool rest_arg, const char *doc);
-s7_pointer s7_make_safe_function(s7_scheme *sc, const char *name, s7_function fnc, int32_t required_args, int32_t optional_args, bool rest_arg, const char *doc);
+s7_pointer s7_make_function(s7_scheme *sc, const char *name, s7_function fnc, s7_int required_args, s7_int optional_args, bool rest_arg, const char *doc);
+s7_pointer s7_make_safe_function(s7_scheme *sc, const char *name, s7_function fnc, s7_int required_args, s7_int optional_args, bool rest_arg, const char *doc);
 s7_pointer s7_make_typed_function(s7_scheme *sc, const char *name, s7_function f, 
-				  int32_t required_args, int32_t optional_args, bool rest_arg, const char *doc, s7_pointer signature);
+				  s7_int required_args, s7_int optional_args, bool rest_arg, const char *doc, s7_pointer signature);
 
-s7_pointer s7_define_function(s7_scheme *sc, const char *name, s7_function fnc, int32_t required_args, int32_t optional_args, bool rest_arg, const char *doc);
-s7_pointer s7_define_safe_function(s7_scheme *sc, const char *name, s7_function fnc, int32_t required_args, int32_t optional_args, bool rest_arg, const char *doc);
+s7_pointer s7_define_function(s7_scheme *sc, const char *name, s7_function fnc, s7_int required_args, s7_int optional_args, bool rest_arg, const char *doc);
+s7_pointer s7_define_safe_function(s7_scheme *sc, const char *name, s7_function fnc, s7_int required_args, s7_int optional_args, bool rest_arg, const char *doc);
 s7_pointer s7_define_typed_function(s7_scheme *sc, const char *name, s7_function fnc,
-				    int32_t required_args, int32_t optional_args, bool rest_arg, 
+				    s7_int required_args, s7_int optional_args, bool rest_arg, 
 				    const char *doc, s7_pointer signature);
 s7_pointer s7_define_unsafe_typed_function(s7_scheme *sc, const char *name, s7_function fnc,
-					   int32_t required_args, int32_t optional_args, bool rest_arg, 
+					   s7_int required_args, s7_int optional_args, bool rest_arg, 
 					   const char *doc, s7_pointer signature);
 
 s7_pointer s7_make_function_star(s7_scheme *sc, const char *name, s7_function fnc, const char *arglist, const char *doc);
@@ -480,7 +478,7 @@ s7_pointer s7_make_safe_function_star(s7_scheme *sc, const char *name, s7_functi
 void s7_define_function_star(s7_scheme *sc, const char *name, s7_function fnc, const char *arglist, const char *doc);
 void s7_define_safe_function_star(s7_scheme *sc, const char *name, s7_function fnc, const char *arglist, const char *doc);
 void s7_define_typed_function_star(s7_scheme *sc, const char *name, s7_function fnc, const char *arglist, const char *doc, s7_pointer signature);
-s7_pointer s7_define_macro(s7_scheme *sc, const char *name, s7_function fnc, int32_t required_args, int32_t optional_args, bool rest_arg, const char *doc);
+s7_pointer s7_define_macro(s7_scheme *sc, const char *name, s7_function fnc, s7_int required_args, s7_int optional_args, bool rest_arg, const char *doc);
 
   /* s7_make_function creates a Scheme function object from the s7_function 'fnc'.
    *   Its name (for s7_describe_object) is 'name', it requires 'required_args' arguments,
@@ -539,7 +537,7 @@ s7_pointer s7_apply_function(s7_scheme *sc, s7_pointer fnc, s7_pointer args);
 s7_pointer s7_apply_function_star(s7_scheme *sc, s7_pointer fnc, s7_pointer args);
 
 s7_pointer s7_call(s7_scheme *sc, s7_pointer func, s7_pointer args);
-s7_pointer s7_call_with_location(s7_scheme *sc, s7_pointer func, s7_pointer args, const char *caller, const char *file, int32_t line);
+s7_pointer s7_call_with_location(s7_scheme *sc, s7_pointer func, s7_pointer args, const char *caller, const char *file, s7_int line);
   
   /* s7_call takes a Scheme function (e.g. g_car above), and applies it to 'args' (a list of arguments) returning the result.
    *   s7_integer(s7_call(s7, g_car, s7_cons(s7, s7_make_integer(s7, 123), s7_nil(s7))));
@@ -554,31 +552,31 @@ bool s7_is_dilambda(s7_pointer obj);
 s7_pointer s7_dilambda(s7_scheme *sc, 
 		       const char *name,
 		       s7_pointer (*getter)(s7_scheme *sc, s7_pointer args), 
-		       int32_t get_req_args, int32_t get_opt_args,
+		       s7_int get_req_args, s7_int get_opt_args,
 		       s7_pointer (*setter)(s7_scheme *sc, s7_pointer args),
-		       int32_t set_req_args, int32_t set_opt_args,
+		       s7_int set_req_args, s7_int set_opt_args,
 		       const char *documentation);
 s7_pointer s7_typed_dilambda(s7_scheme *sc, 
 		       const char *name,
 		       s7_pointer (*getter)(s7_scheme *sc, s7_pointer args), 
-		       int32_t get_req_args, int32_t get_opt_args,
+		       s7_int get_req_args, s7_int get_opt_args,
 		       s7_pointer (*setter)(s7_scheme *sc, s7_pointer args),
-		       int32_t set_req_args, int32_t set_opt_args,
+		       s7_int set_req_args, s7_int set_opt_args,
 		       const char *documentation,
  		       s7_pointer get_sig, s7_pointer set_sig);
 
-s7_pointer s7_values(s7_scheme *sc, s7_pointer args);
+s7_pointer s7_values(s7_scheme *sc, s7_pointer args);          /* (values ...) */
 
-s7_pointer s7_make_iterator(s7_scheme *sc, s7_pointer e);
-bool s7_is_iterator(s7_pointer obj);
-bool s7_iterator_is_at_end(s7_scheme *sc, s7_pointer obj);
-s7_pointer s7_iterate(s7_scheme *sc, s7_pointer iter);
+s7_pointer s7_make_iterator(s7_scheme *sc, s7_pointer e);      /* (make-iterator e) */
+bool s7_is_iterator(s7_pointer obj);                           /* (iterator? obj) */
+bool s7_iterator_is_at_end(s7_scheme *sc, s7_pointer obj);     /* (iterator-at-end? obj) */
+s7_pointer s7_iterate(s7_scheme *sc, s7_pointer iter);         /* (iterate iter) */
 
-void s7_autoload_set_names(s7_scheme *sc, const char **names, int32_t size);
+void s7_autoload_set_names(s7_scheme *sc, const char **names, s7_int size);
 
-s7_pointer s7_copy(s7_scheme *sc, s7_pointer args);
-s7_pointer s7_fill(s7_scheme *sc, s7_pointer args);
-s7_pointer s7_type_of(s7_pointer arg);
+s7_pointer s7_copy(s7_scheme *sc, s7_pointer args);            /* (copy ...) */
+s7_pointer s7_fill(s7_scheme *sc, s7_pointer args);            /* (fill! ...) */
+s7_pointer s7_type_of(s7_pointer arg);                         /* (type-of arg) */
 
 
 
@@ -586,29 +584,29 @@ s7_pointer s7_type_of(s7_pointer arg);
 /* c types/objects */
 
 bool s7_is_c_object(s7_pointer p);
-int32_t s7_c_object_type(s7_pointer obj);
+s7_int s7_c_object_type(s7_pointer obj);
 void *s7_c_object_value(s7_pointer obj);
-void *s7_c_object_value_checked(s7_pointer obj, int32_t type);
-s7_pointer s7_make_c_object(s7_scheme *sc, int32_t type, void *value);
-s7_pointer s7_make_c_object_with_let(s7_scheme *sc, int32_t type, void *value, s7_pointer let);
+void *s7_c_object_value_checked(s7_pointer obj, s7_int type);
+s7_pointer s7_make_c_object(s7_scheme *sc, s7_int type, void *value);
+s7_pointer s7_make_c_object_with_let(s7_scheme *sc, s7_int type, void *value, s7_pointer let);
 void s7_mark_c_object(s7_pointer p);
 s7_pointer s7_c_object_let(s7_pointer obj);
 s7_pointer s7_c_object_set_let(s7_pointer obj, s7_pointer e);
 
-int32_t s7_make_c_type(s7_scheme *sc, const char *name);
-void s7_c_type_set_print         (s7_scheme *sc, int32_t tag, char *(*print)(s7_scheme *sc, void *value));
-void s7_c_type_set_print_readably(s7_scheme *sc, int32_t tag, char *(*printer)(s7_scheme *sc, void *val));
-void s7_c_type_set_free          (s7_scheme *sc, int32_t tag, void (*gc_free)(void *value));
-void s7_c_type_set_equal         (s7_scheme *sc, int32_t tag, bool (*equal)(void *val1, void *val2));
-void s7_c_type_set_mark          (s7_scheme *sc, int32_t tag, void (*gc_mark)(void *val));
-void s7_c_type_set_apply         (s7_scheme *sc, int32_t tag, s7_pointer (*ref)(s7_scheme *sc, s7_pointer obj, s7_pointer args));
-void s7_c_type_set_apply_direct  (s7_scheme *sc, int32_t tag, s7_pointer (*dref)(s7_scheme *sc, s7_pointer obj, s7_int index));
-void s7_c_type_set_set           (s7_scheme *sc, int32_t tag, s7_pointer (*set)(s7_scheme *sc, s7_pointer obj, s7_pointer args));
-void s7_c_type_set_set_direct    (s7_scheme *sc, int32_t tag, s7_pointer (*dset)(s7_scheme *sc, s7_pointer obj, s7_int index, s7_pointer val));
-void s7_c_type_set_length        (s7_scheme *sc, int32_t tag, s7_pointer (*length)(s7_scheme *sc, s7_pointer obj));
-void s7_c_type_set_copy          (s7_scheme *sc, int32_t tag, s7_pointer (*copy)(s7_scheme *sc, s7_pointer args));
-void s7_c_type_set_fill          (s7_scheme *sc, int32_t tag, s7_pointer (*fill)(s7_scheme *sc, s7_pointer args));
-void s7_c_type_set_reverse       (s7_scheme *sc, int32_t tag, s7_pointer (*reverse)(s7_scheme *sc, s7_pointer args));
+s7_int s7_make_c_type(s7_scheme *sc, const char *name);
+void s7_c_type_set_print         (s7_scheme *sc, s7_int tag, char *(*print)(s7_scheme *sc, void *value));
+void s7_c_type_set_print_readably(s7_scheme *sc, s7_int tag, char *(*printer)(s7_scheme *sc, void *val));
+void s7_c_type_set_free          (s7_scheme *sc, s7_int tag, void (*gc_free)(void *value));
+void s7_c_type_set_equal         (s7_scheme *sc, s7_int tag, bool (*equal)(void *val1, void *val2));
+void s7_c_type_set_mark          (s7_scheme *sc, s7_int tag, void (*gc_mark)(void *val));
+void s7_c_type_set_apply         (s7_scheme *sc, s7_int tag, s7_pointer (*ref)    (s7_scheme *sc, s7_pointer obj, s7_pointer args));
+void s7_c_type_set_apply_direct  (s7_scheme *sc, s7_int tag, s7_pointer (*dref)   (s7_scheme *sc, s7_pointer obj, s7_int index));
+void s7_c_type_set_set           (s7_scheme *sc, s7_int tag, s7_pointer (*set)    (s7_scheme *sc, s7_pointer obj, s7_pointer args));
+void s7_c_type_set_set_direct    (s7_scheme *sc, s7_int tag, s7_pointer (*dset)   (s7_scheme *sc, s7_pointer obj, s7_int index, s7_pointer val));
+void s7_c_type_set_length        (s7_scheme *sc, s7_int tag, s7_pointer (*length) (s7_scheme *sc, s7_pointer obj));
+void s7_c_type_set_copy          (s7_scheme *sc, s7_int tag, s7_pointer (*copy)   (s7_scheme *sc, s7_pointer args));
+void s7_c_type_set_fill          (s7_scheme *sc, s7_int tag, s7_pointer (*fill)   (s7_scheme *sc, s7_pointer args));
+void s7_c_type_set_reverse       (s7_scheme *sc, s7_int tag, s7_pointer (*reverse)(s7_scheme *sc, s7_pointer args));
 
   /* These functions create a new Scheme object type.  There is a simple example in s7.html.
    *
@@ -798,13 +796,7 @@ s7_pointer s7_apply_n_9(s7_scheme *sc, s7_pointer args,
 #endif
 
 
-#ifdef __cplusplus
-}
-#endif
-
-#endif
-
-
+/* -------------------------------------------------------------------------------- */
 #if DISABLE_DEPRECATED
 #define s7_is_ulong(arg)          s7_is_integer(arg)
 #define s7_ulong(p)               (uint64_t)s7_integer(p)
@@ -815,6 +807,8 @@ s7_pointer s7_apply_n_9(s7_scheme *sc, s7_pointer args,
 #define s7_make_ulong_long(sc, n) s7_make_c_pointer(sc, (void *)n)
 
 #else
+int64_t s7_heap_size(s7_scheme *sc);
+int64_t s7_gc_freed(s7_scheme *sc);
 
 bool s7_is_ulong(s7_pointer arg);
 unsigned long s7_ulong(s7_pointer p);
@@ -839,28 +833,15 @@ typedef s7_double s7_Double;
 
 #define s7_is_constant(Obj) ((!s7_is_symbol(Obj)) || (s7_is_immutable(Obj)))
 
-int32_t s7_new_type(const char *name,
-		char *(*print)(s7_scheme *sc, void *value), 
-		void (*free)(void *value), 
-		bool (*equal)(void *val1, void *val2),
-		void (*gc_mark)(void *val),
-		s7_pointer (*apply)(s7_scheme *sc, s7_pointer obj, s7_pointer args),
-		s7_pointer (*set)(s7_scheme *sc, s7_pointer obj, s7_pointer args));
+s7_int s7_new_type(const char *name,
+		   char *(*print)(s7_scheme *sc, void *value), 
+		   void (*free)(void *value), 
+		   bool (*equal)(void *val1, void *val2),
+		   void (*gc_mark)(void *val),
+		   s7_pointer (*apply)(s7_scheme *sc, s7_pointer obj, s7_pointer args),
+		   s7_pointer (*set)(s7_scheme *sc, s7_pointer obj, s7_pointer args));
 
-int32_t s7_new_type_x(s7_scheme *sc,
-		  const char *name, 
-		  char *(*print)(s7_scheme *sc, void *value), 
-		  void (*free)(void *value), 
-		  bool (*equal)(void *val1, void *val2),
-		  void (*gc_mark)(void *val),
-		  s7_pointer (*apply)(s7_scheme *sc, s7_pointer obj, s7_pointer args),
-		  s7_pointer (*set)(s7_scheme *sc, s7_pointer obj, s7_pointer args),
-		  s7_pointer (*length)(s7_scheme *sc, s7_pointer obj),
-		  s7_pointer (*copy)(s7_scheme *sc, s7_pointer args),
-		  s7_pointer (*reverse)(s7_scheme *sc, s7_pointer obj),
-		  s7_pointer (*fill)(s7_scheme *sc, s7_pointer args));
-
-void s7_object_type_set_direct(int32_t tag, 
+void s7_object_type_set_direct(s7_int tag, 
 			       s7_pointer (*dref)(s7_scheme *sc, s7_pointer obj, s7_int index), 
 			       s7_pointer (*dset)(s7_scheme *sc, s7_pointer obj, s7_int index, s7_pointer val));
 
@@ -879,7 +860,7 @@ void s7_object_type_set_direct(int32_t tag,
 #define s7_symbol_set_access s7_symbol_set_setter
 
 void s7_define_function_with_setter(s7_scheme *sc, const char *name, s7_function get_fnc, 
-				    s7_function set_fnc, int32_t req_args, int32_t opt_args, const char *doc);
+				    s7_function set_fnc, s7_int req_args, s7_int opt_args, const char *doc);
   /* this is now the same as s7_dilambda (different args) */
 
 #define s7_procedure_setter        s7_setter
@@ -892,6 +873,10 @@ void s7_define_function_with_setter(s7_scheme *sc, const char *name, s7_function
  * 
  *        s7 changes
  *
+ * 23-Mar:    s7_peek_char and s7_read_char now return s7_pointer, s7_write_char takes s7_pointer, not int32_t c
+ *            s7_gc_protect and friends now return/take s7_int location, not uint32_t.
+ *            removed s7_new_type_x.
+ * 19-Mar:    int32_t -> s7_int in various functions.
  * 17-Mar:    deprecate s7_ulong and s7_ulong_long functions.
  * 26-Jan-18: s7_set_setter.
  * --------
@@ -1148,3 +1133,10 @@ void s7_define_function_with_setter(s7_scheme *sc, const char *name, s7_function
  *              and s7_scheme arg to new_type print func.
  * 1-Oct-08   version 1.0
  */
+
+
+#ifdef __cplusplus
+}
+#endif
+
+#endif
