@@ -81,6 +81,13 @@ static void post_prefs_error(const char *msg, prefs_info *data);
 
 static GtkWidget *make_basic_row(GtkWidget *box)
 {
+#if GTK_CHECK_VERSION(3, 92, 1)
+  GtkWidget *row;
+  row = gtk_hbox_new(false, 0);
+  sg_box_pack_start(GTK_BOX(box), row, false, false, 0);
+  gtk_widget_set_hexpand(GTK_WIDGET(row), true);
+  gtk_widget_show(row);
+#else
 #if GTK_CHECK_VERSION(3, 0, 0)
   GtkWidget *row, *r;
   r = gtk_event_box_new(); /* not button! */
@@ -98,6 +105,7 @@ static GtkWidget *make_basic_row(GtkWidget *box)
   row = gtk_hbox_new(false, 0);
   sg_box_pack_start(GTK_BOX(box), row, false, false, 0);
   gtk_widget_show(row);
+#endif
 #endif
 
   return(row);
@@ -368,46 +376,67 @@ static gboolean call_arrow_up_press(GtkWidget *w, GdkEventButton *ev, gpointer c
 
 static GtkWidget *make_row_arrows(prefs_info *prf, GtkWidget *box)
 {
-  GtkWidget *ev_up, *ev_down, *up, *down;
+#if (!GTK_CHECK_VERSION(3, 92, 1))
+  GtkWidget *ev_up, *ev_down;
+#endif
+  GtkWidget *up, *down;
 #if GTK_CHECK_VERSION(3, 14, 0)
   GtkIconTheme *icon_theme; 
   icon_theme = gtk_icon_theme_get_default();
 #endif
 
+#if (!GTK_CHECK_VERSION(3, 92, 1))
   ev_down = gtk_event_box_new();
   sg_box_pack_start(GTK_BOX(box), ev_down, false, false, 0);
   gtk_widget_show(ev_down);
-
+#endif
 #if GTK_CHECK_VERSION(3, 14, 0)
   down = gtk_image_new_from_pixbuf(gtk_icon_theme_load_icon(icon_theme, "pan-down-symbolic", 16, (GtkIconLookupFlags)0, NULL)); 
 #else
   down = gtk_arrow_new(GTK_ARROW_DOWN, GTK_SHADOW_ETCHED_OUT);
 #endif
+#if (!GTK_CHECK_VERSION(3, 92, 1))
   gtk_container_add(GTK_CONTAINER(ev_down), down);
+#else
+  sg_box_pack_start(GTK_BOX(box), down, false, false, 0);
+#endif
   gtk_widget_show(down);
 
+#if (!GTK_CHECK_VERSION(3, 92, 1))
   ev_up = gtk_event_box_new();
   sg_box_pack_start(GTK_BOX(box), ev_up, false, false, 0);
   gtk_widget_show(ev_up);
-
+#endif
 #if GTK_CHECK_VERSION(3, 14, 0)
   up = gtk_image_new_from_pixbuf(gtk_icon_theme_load_icon(icon_theme, "pan-up-symbolic", 16, (GtkIconLookupFlags)0, NULL)); 
 #else
   up = gtk_arrow_new(GTK_ARROW_UP, GTK_SHADOW_ETCHED_OUT);
 #endif
+#if (!GTK_CHECK_VERSION(3, 92, 1))
   gtk_container_add(GTK_CONTAINER(ev_up), up);
+#else
+  sg_box_pack_start(GTK_BOX(box), up, false, false, 0);
+#endif
   gtk_widget_show(up);
 
   prf->arrow_up = up;
   prf->arrow_down = down;
 
+#if (!GTK_CHECK_VERSION(3, 92, 1))
   SG_SIGNAL_CONNECT(ev_down, "button_press_event", call_arrow_down_press, (gpointer)prf);
   SG_SIGNAL_CONNECT(ev_down, "button_release_event", remove_arrow_func, (gpointer)prf);
   SG_SIGNAL_CONNECT(ev_up, "button_press_event", call_arrow_up_press, (gpointer)prf);
   SG_SIGNAL_CONNECT(ev_up, "button_release_event", remove_arrow_func, (gpointer)prf);
   SG_SIGNAL_CONNECT(ev_down, "button_press_event", prefs_change_callback, NULL);
   SG_SIGNAL_CONNECT(ev_up, "button_press_event", prefs_change_callback, NULL);
-
+#else
+  SG_SIGNAL_CONNECT(down, "button_press_event", call_arrow_down_press, (gpointer)prf);
+  SG_SIGNAL_CONNECT(down, "button_release_event", remove_arrow_func, (gpointer)prf);
+  SG_SIGNAL_CONNECT(up, "button_press_event", call_arrow_up_press, (gpointer)prf);
+  SG_SIGNAL_CONNECT(up, "button_release_event", remove_arrow_func, (gpointer)prf);
+  SG_SIGNAL_CONNECT(down, "button_press_event", prefs_change_callback, NULL);
+  SG_SIGNAL_CONNECT(up, "button_press_event", prefs_change_callback, NULL);
+#endif
   return(up);
 }
 
@@ -426,7 +455,7 @@ static prefs_info *prefs_row_with_toggle(const char *label, const char *varname,
 					 GtkWidget *box,
 					 void (*toggle_func)(prefs_info *prf))
 {
-  prefs_info *prf = NULL;
+  prefs_info *prf;
   GtkWidget *hb, *row;
 
   prf = (prefs_info *)calloc(1, sizeof(prefs_info));
@@ -467,7 +496,7 @@ static prefs_info *prefs_row_with_two_toggles(const char *label, const char *var
 					      void (*toggle_func)(prefs_info *prf),
 					      void (*toggle2_func)(prefs_info *prf))
 {
-  prefs_info *prf = NULL;
+  prefs_info *prf;
   GtkWidget *row, *hb;
 
   prf = (prefs_info *)calloc(1, sizeof(prefs_info));
@@ -596,7 +625,7 @@ static prefs_info *prefs_row_with_toggle_with_text(const char *label, const char
 						   void (*toggle_func)(prefs_info *prf),
 						   void (*text_func)(prefs_info *prf))
 {
-  prefs_info *prf = NULL;
+  prefs_info *prf;
   GtkWidget *hb, *row;
 
   prf = (prefs_info *)calloc(1, sizeof(prefs_info));
@@ -632,7 +661,7 @@ static prefs_info *prefs_row_with_toggle_with_two_texts(const char *label, const
 							void (*toggle_func)(prefs_info *prf),
 							void (*text_func)(prefs_info *prf))
 {
-  prefs_info *prf = NULL;
+  prefs_info *prf;
   GtkWidget *hb, *row;
   prf = (prefs_info *)calloc(1, sizeof(prefs_info));
   prf->var_name = varname;
@@ -672,7 +701,7 @@ static prefs_info *prefs_row_with_text_with_toggle(const char *label, const char
 						   void (*toggle_func)(prefs_info *prf),
 						   void (*text_func)(prefs_info *prf))
 {
-  prefs_info *prf = NULL;
+  prefs_info *prf;
   GtkWidget *hb, *row;
 
   prf = (prefs_info *)calloc(1, sizeof(prefs_info));
@@ -711,7 +740,7 @@ static prefs_info *prefs_row_with_text_and_three_toggles(const char *label, cons
 							 GtkWidget *box,
 							 void (*text_func)(prefs_info *prf))
 {
-  prefs_info *prf = NULL;
+  prefs_info *prf;
   GtkWidget *hb, *row;
 
   prf = (prefs_info *)calloc(1, sizeof(prefs_info));
@@ -796,7 +825,7 @@ static prefs_info *prefs_row_with_radio_box(const char *label, const char *varna
 					    GtkWidget *box,
 					    void (*toggle_func)(prefs_info *prf))
 {
-  prefs_info *prf = NULL;
+  prefs_info *prf;
   GtkWidget *hb, *row;
   prf = (prefs_info *)calloc(1, sizeof(prefs_info));
   prf->var_name = varname;
@@ -826,7 +855,7 @@ static prefs_info *prefs_row_with_radio_box_and_number(const char *label, const
 						       void (*arrow_up_func)(prefs_info *prf), void (*arrow_down_func)(prefs_info *prf), 
 						       void (*text_func)(prefs_info *prf))
 {
-  prefs_info *prf = NULL;
+  prefs_info *prf;
   GtkWidget *row, *hb;
   prf = (prefs_info *)calloc(1, sizeof(prefs_info));
   prf->var_name = varname;
@@ -887,7 +916,7 @@ static prefs_info *prefs_row_with_scale(const char *label, const char *varname,
 					void (*scale_func)(prefs_info *prf),
 					void (*text_func)(prefs_info *prf))
 {
-  prefs_info *prf = NULL;
+  prefs_info *prf;
   GtkWidget *hb, *row;
   char *str;
 
@@ -934,7 +963,7 @@ static prefs_info *prefs_row_with_text(const char *label, const char *varname, c
 				       GtkWidget *box,
 				       void (*text_func)(prefs_info *prf))
 {
-  prefs_info *prf = NULL;
+  prefs_info *prf;
   GtkWidget *hb, *row;
 
   prf = (prefs_info *)calloc(1, sizeof(prefs_info));
@@ -965,7 +994,7 @@ static prefs_info *prefs_row_with_two_texts(const char *label, const char *varna
 					    GtkWidget *box,
 					    void (*text_func)(prefs_info *prf))
 {
-  prefs_info *prf = NULL;
+  prefs_info *prf;
   GtkWidget *hb, *row;
   prf = (prefs_info *)calloc(1, sizeof(prefs_info));
   prf->var_name = varname;
@@ -1000,7 +1029,7 @@ static prefs_info *prefs_row_with_number(const char *label, const char *varname,
  					 void (*arrow_up_func)(prefs_info *prf), void (*arrow_down_func)(prefs_info *prf), 
 					 void (*text_func)(prefs_info *prf))
 {
-  prefs_info *prf = NULL;
+  prefs_info *prf;
   GtkWidget *hb, *row;
 
   prf = (prefs_info *)calloc(1, sizeof(prefs_info));
@@ -1039,7 +1068,7 @@ static prefs_info *prefs_row_with_list(const char *label, const char *varname, c
 				       char *(*completion_func)(widget_t w, const char *text, void *context), void *completion_context)
 {
   int i;
-  prefs_info *prf = NULL;
+  prefs_info *prf;
   GtkWidget *hb, *row;
 
   prf = (prefs_info *)calloc(1, sizeof(prefs_info));
@@ -1087,13 +1116,12 @@ static void pixel_to_rgb(color_t pix, double *r, double *g, double *b)
   (*b) = rgb_to_float(pix->blue);
 }
 
-
+#if GTK_CHECK_VERSION(3, 92, 0)
+static void display_color(GtkWidget *w, color_t pixel) {}
+#else
 #if GTK_CHECK_VERSION(3, 0, 0)
 static void display_color(GtkWidget *w, color_t pixel)
 {
-#if GTK_CHECK_VERSION(3, 92, 1)
-  return;
-#else
   cairo_t *cr;
 #if GTK_CHECK_VERSION(3, 22, 0)
   GdkWindow *window;
@@ -1112,10 +1140,9 @@ static void display_color(GtkWidget *w, color_t pixel)
 #else
   cairo_destroy(cr);
 #endif
-#endif
 }
 #endif
-
+#endif
 
 static void scale_set_color(prefs_info *prf, color_t pixel)
 {
@@ -1246,7 +1273,20 @@ static void prefs_call_color_func_callback(GtkWidget *w, gpointer context)
     }
 }
 
+#if GTK_CHECK_VERSION(3, 92, 0)
+static void drawer_expose(GtkDrawingArea *w, cairo_t *cr, int width, int height, gpointer data)
+{
+  prefs_info *prf = (prefs_info *)data;
+  mus_float_t r, g, b;
 
+  r = ADJUSTMENT_VALUE(prf->radj);
+  g = ADJUSTMENT_VALUE(prf->gadj);
+  b = ADJUSTMENT_VALUE(prf->badj);
+
+  cairo_set_source_rgb(cr, r, g, b);
+  cairo_paint(cr);
+}
+#else
 #if GTK_CHECK_VERSION(3, 0, 0)
 static gboolean drawer_expose(GtkWidget *w, GdkEventExpose *ev, gpointer data)
 {
@@ -1263,14 +1303,14 @@ static gboolean drawer_expose(GtkWidget *w, GdkEventExpose *ev, gpointer data)
   return(false);
 }
 #endif
-
+#endif
 
 static prefs_info *prefs_color_selector_row(const char *label, const char *varname, 
 					    color_t current_pixel,
 					    GtkWidget *box,
 					    void (*color_func)(prefs_info *prf, double r, double g, double b))
 {
-  prefs_info *prf = NULL;
+  prefs_info *prf;
   GtkWidget *hb, *row, *row2, *sep3;
   double r = 0.0, g = 0.0, b = 0.0;
 
@@ -1300,12 +1340,18 @@ static prefs_info *prefs_color_selector_row(const char *label, const char *varna
     prf->color = gtk_drawing_area_new();
     gtk_container_add(GTK_CONTAINER(frame), prf->color);
 
+#if GTK_CHECK_VERSION(3, 92, 0)
+    gtk_drawing_area_set_content_width(GTK_DRAWING_AREA(prf->color), widget_width(prf->color));
+    gtk_drawing_area_set_content_height(GTK_DRAWING_AREA(prf->color), widget_height(prf->color));
+    gtk_drawing_area_set_draw_func(GTK_DRAWING_AREA(prf->color), drawer_expose, prf, NULL);
+#else
 #if GTK_CHECK_VERSION(3, 0, 0)
     SG_SIGNAL_CONNECT(prf->color, DRAW_SIGNAL, drawer_expose, prf);
     gtk_widget_set_hexpand(GTK_WIDGET(prf->color), true);
     gtk_widget_set_vexpand(GTK_WIDGET(prf->color), true);
 #else
     widget_modify_bg(prf->color, GTK_STATE_NORMAL, current_pixel);
+#endif
 #endif
     gtk_widget_show(prf->color);
     gtk_widget_show(frame);
@@ -2274,6 +2320,7 @@ widget_t make_preferences_dialog(void)
 
     /* ---------------- (graph) colors ---------------- */
 
+
     make_inter_variable_separator(grf_box); 
     make_inner_label("  colors", grf_box);
 
@@ -2642,7 +2689,6 @@ widget_t make_preferences_dialog(void)
 				aud_box,
 				dac_combines_channels_toggle);
     remember_pref(prf, reflect_dac_combines_channels, save_dac_combines_channels, help_dac_combines_channels, NULL, revert_dac_combines_channels);
-
   }
 
   set_dialog_widget(PREFERENCES_DIALOG, preferences_dialog);
