@@ -169,7 +169,7 @@ static mark *find_mark_from_id(int id, chan_info **cps, int pos)
     {
       chan_info *cp;
       snd_info *sp;
-      unsigned int j;
+      uint32_t j;
       sp = ss->sounds[i];
       if ((sp) && (sp->inuse == SOUND_NORMAL))
 	for (j = 0; j < sp->nchans; j++)
@@ -710,9 +710,9 @@ typedef struct {
 
 void *sound_store_marks(snd_info *sp)
 {
-  unsigned int i;
-  mark_info **res = NULL;
-  marks_info *rtn = NULL;
+  uint32_t i;
+  mark_info **res;
+  marks_info *rtn;
   res = (mark_info **)calloc(sp->nchans, sizeof(mark_info *));
   rtn = (marks_info *)calloc(1, sizeof(marks_info));
   rtn->ms = res;
@@ -1433,7 +1433,11 @@ static void erase_and_draw_grf_points(mark_context *ms, chan_info *cp, int nj)
   ax = draw_cp->ax;
 
 #if USE_GTK
+#if (GTK_CHECK_VERSION(3, 89, 0))
+  ss->cr = cp->graph_cr;
+#else
   ss->cr = make_cairo(ax->wn);
+#endif
 #endif
 
   undraw_gc = erase_GC(draw_cp);
@@ -1456,7 +1460,9 @@ static void erase_and_draw_grf_points(mark_context *ms, chan_info *cp, int nj)
   ax->gc = draw_gc;
 
 #if USE_GTK
+#if (!GTK_CHECK_VERSION(3, 89, 0))
   free_cairo(ss->cr);
+#endif
   ss->cr = NULL;
 #endif
 }
@@ -1480,7 +1486,11 @@ static void erase_and_draw_both_grf_points(mark_context *ms, chan_info *cp, int
   ax = draw_cp->ax;
 
 #if USE_GTK
+#if (GTK_CHECK_VERSION(3, 89, 0))
+  ss->cr = cp->graph_cr;
+#else
   ss->cr = make_cairo(ax->wn);
+#endif
 #endif
 
   undraw_gc = erase_GC(draw_cp);
@@ -1507,7 +1517,9 @@ static void erase_and_draw_both_grf_points(mark_context *ms, chan_info *cp, int
   ax->gc = draw_gc;
 
 #if USE_GTK
+#if (!GTK_CHECK_VERSION(3, 89, 0))
   free_cairo(ss->cr);
+#endif
   ss->cr = NULL;
 #endif
 }
@@ -1915,7 +1927,11 @@ static void show_mark(chan_info *cp, mark *mp, bool show)
 
   ax = mark_tag_context(cp);
 #if USE_GTK
+#if (GTK_CHECK_VERSION(3, 89, 0))
+  ss->cr = cp->graph_cr;
+#else
   ss->cr = make_cairo(ax->wn);
+#endif
 #endif
 
   if (mp->name)
@@ -1944,7 +1960,9 @@ static void show_mark(chan_info *cp, mark *mp, bool show)
 		 cx, y0);
   mp->visible = show;
 #if USE_GTK
+#if (!GTK_CHECK_VERSION(3, 89, 0))
   free_cairo(ss->cr);
+#endif
   ss->cr = NULL;
   copy_context(cp);
 #endif
@@ -2178,22 +2196,18 @@ static Xen mark_get(Xen n, mark_field_t fld, Xen pos_n, const char *caller)
     {
     case MARK_SAMPLE: 
       return(C_llong_to_Xen_llong(m->samp)); 
-      break;
 
     case MARK_SYNC:   
       return(C_int_to_Xen_integer(m->sync)); 
-      break;
 
     case MARK_NAME:   
       if (m->name) 
 	return(C_string_to_Xen_string(m->name)); 
-      else return(C_string_to_Xen_string("")); 
-      break;
+      return(C_string_to_Xen_string("")); 
 
     case MARK_HOME:   
       return(Xen_list_2(C_int_to_Xen_sound((ncp[0]->sound)->index),
 			C_int_to_Xen_integer(ncp[0]->chan))); 
-      break;
     }
   return(Xen_false);
 }
@@ -2755,7 +2769,7 @@ void save_mark_list(FILE *fd, chan_info *cp, bool all_chans)
   sv->syncs = NULL;
   if (all_chans)
     {
-      unsigned int i;
+      uint32_t i;
       snd_info *sp;
       sp = cp->sound;
       for (i = 0; i < sp->nchans; i++)
