@@ -313,12 +313,10 @@ static mus_float_t region_sample(int reg, int chn, mus_long_t samp)
 	      val = read_sample(sf);
 	      free_snd_fd(sf);
 	      return(val);
-	      break;
 
 	    case REGION_DEFERRED:
 	      drp = r->dr;
 	      return(chn_sample(samp + r->begs[chn], drp->cps[chn], drp->edpos[chn]));
-	      break;
 	    }
 	}
     }
@@ -334,10 +332,8 @@ mus_long_t region_current_location(snd_fd *fd)
     {
     case REGION_FILE:
       return(current_location(fd));
-      break;
     case REGION_DEFERRED:
       return(current_location(fd) - r->begs[0]);
-      break;
     }
   return(-1);
 }
@@ -1758,11 +1754,11 @@ static Xen region_get(region_field_t field, Xen n, const char *caller)
 
   switch (field)
     {
-    case REGION_SRATE:  return(C_int_to_Xen_integer(region_srate(rg)));                              break;
-    case REGION_CHANS:  return(C_int_to_Xen_integer(region_chans(rg)));                              break;
-    case REGION_MAXAMP: return(C_double_to_Xen_real(region_maxamp(rg)));                             break;
-    case REGION_MAXAMP_POSITION: return(C_llong_to_Xen_llong(region_maxamp_position(rg)));           break;
-    case REGION_FORGET: delete_region_and_update_browser(region_id_to_list_position(rg)); return(n); break;
+    case REGION_SRATE:  return(C_int_to_Xen_integer(region_srate(rg)));                              
+    case REGION_CHANS:  return(C_int_to_Xen_integer(region_chans(rg)));                              
+    case REGION_MAXAMP: return(C_double_to_Xen_real(region_maxamp(rg)));                             
+    case REGION_MAXAMP_POSITION: return(C_llong_to_Xen_llong(region_maxamp_position(rg)));           
+    case REGION_FORGET: delete_region_and_update_browser(region_id_to_list_position(rg)); return(n); 
     case REGION_HOME:
       {
 	region *r;
