@@ -18,7 +18,7 @@ static bool map_over_chans(bool (*func)(chan_info *ncp))
 
   for (i = 0; i < ss->max_sounds; i++)
     {
-      unsigned int j;
+      uint32_t j;
       snd_info *sp;
       chan_info *cp;
       sp = ss->sounds[i];
@@ -77,7 +77,7 @@ static mus_long_t mus_long_t_map_over_chans(mus_long_t (*func)(chan_info *, mus_
 
   for (i = 0; i < ss->max_sounds; i++)
     {
-      unsigned int j;
+      uint32_t j;
       snd_info *sp;
       chan_info *cp;
 
@@ -369,7 +369,7 @@ sync_info *selection_sync(void)
 
 static int mix_selection(chan_info *cp, sync_info *si_out, mus_long_t beg, io_error_t *err, int start_chan)
 {
-  char *tempfile = NULL;
+  char *tempfile;
   int id = INVALID_MIX_ID;
   io_error_t io_err;
 
@@ -619,7 +619,7 @@ static void redraw_selection(void)
 	{
 	  if (sp->inuse == SOUND_NORMAL)
 	    {
-	      unsigned int j;
+	      uint32_t j;
 	      for (j = 0; j < sp->nchans; j++)
 		{
 		  chan_info *cp;
@@ -1077,7 +1077,7 @@ io_error_t save_selection(const char *ofile, int srate, mus_sample_t samp_type,
   int ofd;
   io_error_t io_err = IO_NO_ERROR;
   mus_long_t oloc, alloc_len;
-  sync_info *si = NULL;
+  sync_info *si;
   mus_long_t *ends;
   int i, j, k, chans;
   mus_long_t dur;
@@ -1400,7 +1400,7 @@ static Xen g_selection_to_mix(void)
       int i, id = INVALID_MIX_ID, chans = 0, sync = GET_NEW_SYNC;
       sync_info *si_out;
       Xen result = Xen_empty_list;
-      char *tempfile = NULL, *origin = NULL;
+      char *tempfile, *origin = NULL;
 
       si_out = selection_sync();
       cp = si_out->cps[0];
