@@ -180,7 +180,7 @@ char *just_filename(char *name)
 char *just_directory(const char *name)
 {
   int i, len, last_slash = 0;
-  char *dirname = NULL;
+  char *dirname;
   len = strlen(name);
   dirname = (char *)calloc(len + 1, sizeof(char));
   for (i = 0; i < len - 1; i++) 
@@ -272,7 +272,7 @@ char *prettyf(double num, int tens)
 
 static char *get_tmpdir(void)
 {
-  char *tmpdir = NULL;
+  char *tmpdir;
   int len;
   tmpdir = mus_strdup(getenv("TMPDIR"));
   if ((!tmpdir) && (MUS_DEFAULT_TEMP_DIR)) tmpdir = mus_strdup(MUS_DEFAULT_TEMP_DIR);
@@ -298,13 +298,20 @@ char *shorter_tempnam(const char *udir, const char *prefix)
   if ((!udir) || (mus_strlen(udir) == 0)) 
     tmpdir = get_tmpdir(); /* incoming dir could be "" */
   else tmpdir = mus_strdup(udir);
-  snprintf(str, PRINT_BUFFER_SIZE, "%s%s%s%d_%d.snd", 
-	   tmpdir, 
-	   (tmpdir[strlen(tmpdir) - 1] == '/') ? "" : "/",
-	   (prefix) ? prefix : "snd_", 
-	   (int)getpid(), 
-	   sect_ctr++);
-  if (tmpdir) free(tmpdir);
+  if (tmpdir)
+    {
+      snprintf(str, PRINT_BUFFER_SIZE, "%s%s%s%d_%d.snd", 
+	       tmpdir, 
+	       (tmpdir[strlen(tmpdir) - 1] == '/') ? "" : "/",
+	       (prefix) ? prefix : "snd_", 
+	       (int)getpid(), 
+	       sect_ctr++);
+      free(tmpdir);
+    }
+  else snprintf(str, PRINT_BUFFER_SIZE, "%s%d_%d.snd", 
+		(prefix) ? prefix : "snd_", 
+		(int)getpid(), 
+		sect_ctr++);
   tmpdir = mus_strdup(str);
   free(str);
   return(tmpdir);
