@@ -19,6 +19,10 @@
 
 ;(define sequence? length) -- now built-in for signatures
 
+(define (nth-value n . args) ; untested...
+  (and (> (length args) n)
+       (list-ref args n)))
+
 (define indexable? 
   (let ((+documentation+ "(indexable? obj) returns #t if obj can be applied to an index: (obj 0)"))
     (lambda (obj)
@@ -524,6 +528,8 @@ If func approves of one, index-if returns the index that gives that element's po
   (let ((+documentation+ "(collect-if type func sequence) gathers the elements of sequence that satisfy func, and returns them via type:\n\
     (collect-if list integer? #(1.4 2/3 1 1+i 2)) -> '(1 2)"))
     (lambda (type f sequence)
+      (unless (sequence? sequence)
+	(error 'wrong-type-arg "collect-if: sequence arg is ~A" sequence))
       (apply type (map (lambda (arg) (if (f arg) arg (values))) sequence)))))
 
 ;;; if type=list, this is slightly wasteful because list currently copies its args, so:
@@ -535,6 +541,8 @@ If func approves of one, index-if returns the index that gives that element's po
   (let ((+documentation+ "(remove-if type f sequence) returns via type the elements of sequence that do not satisfy func:\n\
     (remove-if list integer? #(1.4 2/3 1 1+i 2)) -> '(1.4 2/3 1+1i)"))
     (lambda (type f sequence)
+      (unless (sequence? sequence)
+	(error 'wrong-type-arg "remove-if: sequence arg is ~A" sequence))
       (collect-if type (lambda (obj) (not (f obj))) sequence))))
 
 (define nonce 
@@ -609,7 +617,7 @@ If func approves of one, index-if returns the index that gives that element's po
 	    (make-iterator
 	     (cond ((infinite? len)      ; circular list
 		    (let ((cur p)
-			  (iterator? #t))
+			  (+iterator+ #t))
 		      (lambda ()
 			(if (memq cur seen-cycles)
 			    #<eof>
@@ -622,7 +630,7 @@ If func approves of one, index-if returns the index that gives that element's po
 		    p)
 		   (else 
 		    (let ((cur p)        ; dotted list
-			  (iterator? #t))
+			  (+iterator+ #t))
 		      (lambda ()
 			(if (pair? cur)
 			    (let ((result (car cur)))
@@ -634,7 +642,7 @@ If func approves of one, index-if returns the index that gives that element's po
     
     (make-iterator
      (let ((iter (make-careful-iterator obj))
-	   (iterator? #t))       
+	   (+iterator+ #t))       
        (define (iterloop) ; define returns the new value
 	 (define (iter-memq p q)
 	   (and (pair? q)
@@ -853,6 +861,10 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
   (and (integer? x)
        (zero? (logand x (+ x 1)))))
 
+(define (2-ruler n) ; translated from CLOCC cllib/math.lisp, ruler
+  ;; The exponent of the largest power of 2 which divides the given number.
+  (- (integer-length (logand n (- n))) 1))
+
 (define (lognand . ints) 
   (lognot (apply logand ints)))
 
@@ -2114,7 +2126,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 	 (let ((dir (opendir name)))
 	   (if (equal? dir NULL)
 	       (error 'io-error "can't open ~S: ~S" name (strerror (errno)))
-	       (let ((iterator? #t))
+	       (let ((+iterator+ #t))
 		 (define reader
 		   (let ((dirs ())
 			 (dir-names ())
