@@ -75,9 +75,9 @@
 (set! (*s7* 'autoloading?) #f)
 (set! (*s7* 'morally-equal-float-epsilon) 1.0e-6)
 (set! (current-output-port) #f)
-(define startup-input-port (current-input-port))
 
 (define ostr "")
+(define estr "")
 (define nostr "")
 
 (define __var__ #f)
@@ -88,7 +88,6 @@
 (define false #f)
 (define _undef_ (car (with-input-from-string "(#_asdf 1 2)" read)))
 (define kar car)
-;(set! (setter kar) (lambda (x) car))
 (set! (setter kar) (lambda (x) (error 'oops "kar not settable: ~A" ostr)))
 (define-constant _1234_ 1234)
 (define _dilambda_ (dilambda (lambda (x) (+ x 1)) (lambda (x y) (+ x y))))
@@ -110,83 +109,29 @@
 (define (s7-initial-string-port-length) (*s7* 'initial-string-port-length))
 (define (s7-safety) (*s7* 'safety))
 (define (s7-set-safety val) (set! (*s7* 'safety) val))
-#|
-(define (s7-undefined-identifier-warnings) (*s7* 'undefined-identifier-warnings))
 (define (s7-autoloading?) (*s7* 'autoloading?))
 (define (s7-max-stack-size) (*s7* 'max-stack-size))
 (define (s7-stacktrace-defaults) (*s7* 'stacktrace-defaults))
 (define (s7-gc-stats) (*s7* 'gc-stats))
+(define (s7-undefined-identifier-warnings) (*s7* 'undefined-identifier-warnings))
 
-(define (s7-set-print-length x) 
-  ;(format *stderr* "(~A ~A)~%" 'print-length (object->string x #t 16)) 
-  (set! (*s7* 'print-length) x)
-  ;(format *stderr* "  -> ~A~%" (*s7* 'print-length))
-  )
-(define (s7-set-max-string-length x) 
-  ;(format *stderr* "(~A ~A)~%" 'max-string-length (object->string x #t 16)) 
-  (set! (*s7* 'max-string-length) x)
-  ;(format *stderr* "  -> ~A~%" (*s7* 'max-string-length))
-  )
-(define (s7-set-max-list-length x) 
-  ;(format *stderr* "(~A ~A)~%" 'max-list-length (object->string x #t 16)) 
-  (set! (*s7* 'max-list-length) x)
-  ;(format *stderr* "  -> ~A~%" (*s7* 'max-list-length))
-  )
-(define (s7-set-max-vector-length x)
-  ;(format *stderr* "(~A ~A)~%" 'max-vector-length (object->string x #t 16)) 
-  (set! (*s7* 'max-vector-length) x)
-  ;(format *stderr* "  -> ~A~%" (*s7* 'max-vector-length))
-  )
-(define (s7-set-max-vector-dimensions x)
-  ;(format *stderr* "(~A ~A)~%" 'max-vector-dimensions (object->string x #t 16)) 
-  (set! (*s7* 'max-vector-dimensions) x)
-  ;(format *stderr* "  -> ~A~%" (*s7* 'max-vector-dimensions))
-  )
-(define (s7-set-default-hash-table-length x)
-  ;(format *stderr* "(~A ~A)~%" 'default-hash-table-length (object->string x #t 16)) 
-  (set! (*s7* 'default-hash-table-length) x)
-  ;(format *stderr* "  -> ~A~%" (*s7* 'default-hash-table-length))
-  )
-(define (s7-set-initial-string-port-length x)
-  ;(format *stderr* "(~A ~A)~%" 'initial-string-port-length (object->string x #t 16)) 
-  (set! (*s7* 'initial-string-port-length) x)
-  ;(format *stderr* "  -> ~A~%" (*s7* 'initial-string-port-length))
-  )
-(define (s7-set-undefined-identifier-warnings x)
-  ;(format *stderr* "(~A ~A)~%" 'undefined-identifier-warnings (object->string x #t 16))
-  (set! (*s7* 'undefined-identifier-warnings) x)
-  ;(format *stderr* "  -> ~A~%" (*s7* 'undefined-identifier-warnings))
-  )
-(define (s7-set-autoloading? x)
-  ;(format *stderr* "(~A ~A)~%" 'autoloading? (object->string x #t 16))
-  (set! (*s7* 'autoloading?) x)
-  ;(format *stderr* "  -> ~A~%" (*s7* 'autoloading?))
-  )
-(define (s7-set-max-stack-size x)
-  ;(format *stderr* "(~A ~A)~%" 'max-stack-size (object->string x #t 16))
-  (set! (*s7* 'max-stack-size) x)
-  ;(format *stderr* "  -> ~A~%" *s7* 'max-stack-size)
-  )
-(define (s7-set-stacktrace-defaults x) 
-  ;(format *stderr* "(~A ~A)~%" 'stacktrace-defaults (object->string x #t 16))
-  (set! (*s7* 'stacktrace-defaults) x)
-  ;(format *stderr* "  -> ~A~%" (*s7* 'stacktrace-defaults))
-  )
-(define (s7-set-gc-stats x) 
-  ;(format *stderr* "(~A ~A)~%" 'gc-stats (object->string x #t 16))
-  (set! (*s7* 'gc-stats) x)
-  ;(format *stderr* "  -> ~A~%" *s7* 'gc-stats)
-  )
-(define (s7-set-default-rationalize-error x)
-  ;(format *stderr* "(~A ~A)~%" 'default-rationalize-error (object->string x #t 16)) 
-  (set! (*s7* 'default-rationalize-error) x)
-  ;(format *stderr* "  -> ~A~%" (*s7* 'default-rationalize-error))
-  )
+#|
+(define (s7-set-print-length x) (set! (*s7* 'print-length) x))
+(define (s7-set-max-string-length x) (set! (*s7* 'max-string-length) x))
+(define (s7-set-max-list-length x) (set! (*s7* 'max-list-length) x))
+(define (s7-set-max-vector-length x) (set! (*s7* 'max-vector-length) x))
+(define (s7-set-max-vector-dimensions x) (set! (*s7* 'max-vector-dimensions) x))
+(define (s7-set-default-hash-table-length x) (set! (*s7* 'default-hash-table-length) x))
+(define (s7-set-initial-string-port-length x) (set! (*s7* 'initial-string-port-length) x))
+(define (s7-set-undefined-identifier-warnings x) (set! (*s7* 'undefined-identifier-warnings) x))
+(define (s7-set-autoloading? x) (set! (*s7* 'autoloading?) x))
+(define (s7-set-max-stack-size x) (set! (*s7* 'max-stack-size) x))
+(define (s7-set-stacktrace-defaults x) (set! (*s7* 'stacktrace-defaults) x))
+(define (s7-set-gc-stats x) (set! (*s7* 'gc-stats) x))
+(define (s7-set-default-rationalize-error x) (set! (*s7* 'default-rationalize-error) x))
 
-(define (s7-profile-info) (*s7* 'profile-info))
 (define (s7-catches) (*s7* 'catches))
 (define (s7-exits) (*s7* 'exits))
-(define (s7-c-types) (*s7* 'c-types))
 (define (s7-stack-top) (*s7* 'stack-top))
 (define (s7-stack-size) (*s7* 'stack-size))
 (define (s7-stack) (*s7* 'stack))
@@ -197,30 +142,16 @@
 (define (s7-gc-freed) (*s7* 'gc-freed))
 (define (s7-gc-protected-objects) (*s7* 'gc-protected-objects))
 |#
+(define (s7-c-types) (*s7* 'c-types))
+(define (s7-profile-info) (*s7* 'profile-info))
 (define (s7-memory-usage) (string? (with-output-to-string (lambda () (*s7* 'memory-usage)))))
 (define (s7-history) (*s7* 'history))
 (define (s7-history-size) (*s7* 'history-size))
 
-(define (s7-set-morally-equal-float-epsilon x)
-  ;(format *stderr* "(~A ~A)~%" 'morally-equal-float-epsilon (object->string x #t 16)) 
-  (set! (*s7* 'morally-equal-float-epsilon) x)
-  ;(format *stderr* "  -> ~A~%" (*s7* 'morally-equal-float-epsilon))
-  )
-(define (s7-set-hash-table-float-epsilon x)
-  ;(format *stderr* "(~A ~A)~%" 'hash-table-float-epsilon (object->string x #t 16))
-  (set! (*s7* 'hash-table-float-epsilon) x)
-  ;(format *stderr* "  -> ~A~%" (*s7* 'hash-table-float-epsilon))
-  )
-(define (s7-set-bignum-precision x)
-  ;(format *stderr* "(~A ~A)~%" 'bignum-precision (object->string x #t 16)) 
-  (set! (*s7* 'bignum-precision) x)
-  ;(format *stderr* "  -> ~A~%" (*s7* 'bignum-precision))
-  )
-(define (s7-set-float-format-precision x)
-  ;(format *stderr* "(~A ~A)~%" 'float-format-precision (object->string x #t 16)) 
-  (set! (*s7* 'float-format-precision) x)
-  ;(format *stderr* "  -> ~A~%" (*s7* 'float-format-precision))
-  )
+(define (s7-set-morally-equal-float-epsilon x) (set! (*s7* 'morally-equal-float-epsilon) x))
+(define (s7-set-hash-table-float-epsilon x) (set! (*s7* 'hash-table-float-epsilon) x))
+(define (s7-set-bignum-precision x) (set! (*s7* 'bignum-precision) x))
+(define (s7-set-float-format-precision x) (set! (*s7* 'float-format-precision) x))
 
 (define (s7-default-rationalize-error) (*s7* 'default-rationalize-error))
 (define (s7-morally-equal-float-epsilon) (*s7* 'morally-equal-float-epsilon))
@@ -259,9 +190,9 @@
   (let ((_h_ (make-hash-table (*s7* 'default-hash-table-length) morally-equal?)))
     (do ((key/value args (cdr key/value)))
 	((null? key/value) _h_)
-      (if (not (pair? key/value))
+      (if (not (pair? (car key/value)))
 	  (error 'wrong-type-args "not a pair")
-	  (set! (_h_ (car key/value)) (cdr key/value))))))
+	  (set! (_h_ (caar key/value)) (cdar key/value))))))
 
 
 (load "s7test-block.so" (sublet (curlet) (cons 'init_func 'block_init)))
@@ -399,7 +330,6 @@
 			  'negative? 'cons 'string-set! 'list-ref 'eqv? 'positive? '>= 'expt 'number->string 'zero? 'floor 'denominator 'integer->char 
 			  'string? 'min '<= 'char->integer 'cos 'rationalize 'cadr 'sin 'char=? 'map 'list-set! 'defined? 'memq 'string-ref 'log 
 			  'for-each 'round 'ceiling 'truncate 'string=? 'atan 'eof-object? 'numerator 'char? 'cosh 'member 'vector 
-			  ;;'read-char 'read-byte 'read-line 'read-string 'read ; stdin=>hangs
 			  'even? 'string-append 'char-upcase 'sqrt 'make-string
 			  'char-alphabetic? 'odd? 'call-with-exit 'tanh 'copy 'sinh 'make-vector
 			  'string 'char-ci=? 'caddr 'tan 'reverse 'cddr 'append 'vector? 'list? 'exp 'acos 'asin 'symbol? 'char-numeric? 'string-ci=? 
@@ -411,7 +341,6 @@
 			  'object->string 'char>? 'symbol->value 'cadar 'integer-decode-float 'string-copy 'cdddr 'logand 'cadddr 
 			  'with-input-from-string 'substring 'string->list 'char-upper-case? 
 			  'hash-table-set! 'cddddr 'string<? 'dynamic-wind 'call-with-input-file 'error 
-			  ;;'close-output-port 
 			  'lognot 'cdar 'char-ci>=? 'string>=? 
 			  'dilambda 'string-ci<? 'char<=? 'logior 'char-ci<=? 'assv 
 			  'string>? 'char-ci>? 'char-lower-case? 'string-ci>=? 'string-ci>? 'string<=? 'caadr 'char-ci<? 'reverse! 
@@ -425,8 +354,7 @@
 			  'with-input-from-file 'type-of
 			  'vector-fill! 
 			  'symbol 'peek-char 'make-hash-table 
-			  'close-input-port ;'current-error-port ;-- spurious output
-			  'macro? ;'load
+			  'macro? 
 			  'quasiquote 
 			  'immutable? 'char-position 'string-position
 			  'infinite? 
@@ -436,12 +364,9 @@
 			  'continuation? 'hash-table? 'port-closed? 
 			  'output-port? 'input-port? 
 			  'provide 'call-with-output-string 
-			  ;; 'hash-table 
-			  ;; 'checked-hash-table 'checked-hash-table*
-			  ;;'current-output-port 
+			  'checked-hash-table 'checked-hash-table*
 			  'with-output-to-string 
-			  ;;'current-input-port -- too many (read...)
-			  'symbol-setter ;'unlet -- spurious diffs
+			  'symbol-setter 
 			  's7-version 
 			  'dilambda?
 			  'hook-functions 
@@ -449,29 +374,19 @@
 			  ;; -------- naming funcs
 			  'make-hook 
 			  'let 'let* 'letrec 
-#|
-			  'lambda 'lambda*
-|#
-			  'multiple-value-bind 'call-with-values
+			  ; 'lambda 'lambda*
+			  ; 'multiple-value-bind 'call-with-values
 			  'inlet 
 			  'object->let
 			  ;; --------
 
-                          ;'pair-line-number 
 			  'open-input-string 'open-output-string 
 			  'open-input-file 
 			  'define
 			  'newline
-			  ;'funclet
-			  ;'random 
-			  'random-state ;;'port-line-number -- too many spurious diffs
+			  'random-state 
 			  'gensym
-			  ;'quote
-			  'if 'begin 
-			  
-			  'cond 'case 'or 'and 'do 'with-let 'with-baffle 'when 'unless
-			  
-			  'let-temporarily
+			  'if 'begin 'cond 'case 'or 'and 'do 'with-let 'with-baffle 'when 'unless 'let-temporarily
 			  'byte-vector-set! 'make-byte-vector 
 			  'write-char 'call/cc 'write-byte 'write-string 
 			  'file-mtime
@@ -480,42 +395,60 @@
 			  'outlet 
 			  'directory->list 
 			  'define* 'define-macro 'define-macro* 'define-bacro 'define-bacro*
-			  'set! 'set-car! ;'set-cdr!
+			  'set! 'set-car! 
 			  'call-with-output-file 'with-output-to-file 
+			  ;'read-char 'read-byte 'read-line 'read-string 'read ; stdin=>hangs
+			  ;'close-input-port 
+			  ;'current-input-port ;-- too many (read...) also close of it can close the load port [fixed]
+                          'set-cdr!
+                          ;'unlet ;-- spurious diffs
+                          ;'port-line-number ;-- too many spurious diffs
+			  ;'load  ;'current-error-port ;-- spurious output
+			  ;'close-output-port 
+			  ; 'hash-table 'hash-table*; -- handled as morally equal via checked-hash-table
+			  ;'current-output-port 
 			  ;'cutlet 
 			  ;'set-current-error-port ;-- too many bogus eq? complaints
-			  ;'stacktrace ; -- with eval-string, causes stack to grow continuously? (length (stacktrace)) 
-			  'signature ; -- circular lists cause infinite loops with (e.g.) for-each??
+			  ;'stacktrace ; -- tons of output, with eval-string, causes stack to grow continuously? (length (stacktrace)) 
 			  ;'define-constant 
 			  ;'curlet ; (length (curlet)) too many times
-			  ;'rootlet  ; cyclic-sequences oddness
  			  ;'open-output-file
 			  ;'delete-file 'set-current-output-port 
-			  ;'autoload ;-- possibly causes stack growth
+			  'autoload ;-- possibly causes stack growth
 			  ;'varlet ;-- error exits, chaos in rootlet
-			  ;'tree-count 'tree-leaves 'tree-memq 'tree-set-memq ;-- no cycle checks and we have signature creating circular lists
-			  ;'eval ; -- can't use if signature (circular program)
+			  ;'eval ; -- can't use if signature (circular program) or (make-list (max-list-len))
 			  ;'immutable!
-			  ;'procedure-source -- appears to be the culprit when hook body becomes (apply) after optimization
-			  'eval-string 
-			  ;;'owlet ;too many uninteresting diffs
+			  ;'procedure-source ;-- appears to be the culprit when hook body becomes (apply) after optimization
+			  ;'owlet ;too many uninteresting diffs
 			  ;'gc
-			  ;'reader-cond -- cond test clause can involve unbound vars: (null? i) for example
-                          'require ;'help -- snd goes crazy
+			  ;'reader-cond ;-- cond test clause can involve unbound vars: (null? i) for example
+                          ;'pair-line-number 
+			  ;'funclet
+			  ;'random 
+			  ;'quote
+			  '*error-hook*
+			  ;'cond-expand 
+			  ;'random-state->list 
+			  ;'pair-filename 
+			  ;'let-set! ;-- rootlet troubles?
+			  ;'coverlet ;-- blocks block's morally-equal?
+                          ;'help ;-- snd goes crazy
+			  ;'macroexpand ;-- uninteresting objstr stuff
+			  'signature ; -- circular lists cause infinite loops with (e.g.) for-each??
+			  ;'rootlet  ; cyclic-sequences oddness and rootlet can be stepped on
+			  'eval-string 
+			  'tree-count 'tree-leaves 'tree-memq 'tree-set-memq ;-- no cycle checks and we have signature creating circular lists
+			  'tree-cyclic?
+                          'require
 			  'else '_mac_ '_mac*_ '_bac_ '_bac*_ 
 			  '_fnc_ '_fnc*_ '_fnc1_ '_fnc2_ '_fnc3_ '_fnc4_ '_fnc5_
 			  'block 'make-block 'block?
 			  
 			  'constant?
 			  'openlet 
-			  
-			  ;;'cond-expand 
 			  '*unbound-variable-hook* '*load-hook* '*rootlet-redefinition-hook* '*missing-close-paren-hook* '*read-error-hook* 
 			  '*autoload*
-			  ;;'*error-hook*
-
 			  'sequence? 'directory? 'hash-table-entries 
-			  ;;'hash-table* -- handled as morally equal
 			  'arity 'logbit? 
 			  'random-state? 'throw 'float-vector-set! 'make-iterator 'complex 
 			  'let-ref 'int-vector 'aritable? 'gensym? 'syntax? 'iterator-at-end? 'let? 
@@ -524,27 +457,22 @@
 			  
 			  'setter 'int-vector? 
 			  'int-vector-set! 'c-object? 'proper-list? 'symbol->dynamic-value 'vector-append 
-			  ;'random-state->list ;'pair-filename 
 			  'flush-output-port 'c-pointer 'make-float-vector 
 			  'iterate 'float-vector? 
 			  'apply-values 'values
 			  'byte-vector-ref 'file-exists? 'make-int-vector 'string-downcase 'string-upcase 
 			  'byte-vector 'morally-equal? 
-			  ;;'let-set! -- rootlet troubles?
-			  'c-pointer? 'int-vector-ref ;
-			  ;;'coverlet -- blocks block's morally-equal?
+			  'c-pointer? 'int-vector-ref
 			  'float? 
 			  'list-values 'byte-vector? 'openlet? 'iterator? 
 			  'string->byte-vector
 
 #|
-			  's7-profile-info 
-			  's7-undefined-identifier-warnings 
-                          ;'s7-autoloading? 
 			  's7-catches 's7-exits 
 			  's7-stack-top 's7-stack 
 			  's7-symbol-table 
 			  's7-gc-protected-objects
+			  's7-stacktrace-defaults ; clobbered by reverse!
 
 			  's7-set-print-length 
 			  's7-set-max-string-length 
@@ -556,15 +484,19 @@
 			  's7-set-undefined-identifier-warnings 's7-set-autoloading? 's7-set-max-stack-size
 			  's7-set-stacktrace-defaults
 			  's7-set-gc-stats
-			  ;;'s7-set-default-rationalize-error
-			  ;;'s7-set-morally-equal-float-epsilon 
-			  ;;'s7-set-hash-table-float-epsilon 
-			  ;;'s7-set-bignum-precision 
-			  ;;'s7-set-float-format-precision
+			  's7-set-default-rationalize-error
+			  's7-set-morally-equal-float-epsilon 
+			  's7-set-hash-table-float-epsilon 
+			  's7-set-bignum-precision 
+			  's7-set-float-format-precision
+			  's7-set-safety
 |#
-			  's7-memory-usage
-			  'undefined-function
-			  ;;'s7-safety 's7-set-safety ;-- these need work...
+			  's7-undefined-identifier-warnings 
+			  's7-profile-info 
+			  's7-autoloading? 
+
+			  ;'s7-memory-usage ; too slow
+			  's7-safety 
 			  's7-c-types 
 			  ;;'s7-history ;-- causes stack to grow?
 			  's7-print-length 's7-max-string-length 's7-max-list-length 's7-max-vector-length 's7-max-vector-dimensions 's7-default-hash-table-length
@@ -577,35 +509,35 @@
 			  's7-file-names
 			  's7-autoloading?
 			  's7-rootlet-size 's7-heap-size 's7-free-heap-size 's7-gc-freed 's7-stack-size 's7-max-stack-size 's7-gc-stats
-			  's7-stacktrace-defaults
 
-			  ;'macroexpand ;-- uninteresting objstr stuff
 			  'block-reverse! 'subblock 'unquote 'block-append ;'block-let
+			  'simple-block? 'make-simple-block
 
+			  'undefined-function
 			  ;'subsequence 
 			  'empty? 'indexable? 'first
 			  ;'copy-tree ; cycles cause stack overflow
 			  'adjoin 'cdr-assoc
 			  ;'progv ;'value->symbol -- correctly different values sometimes, progv localizes
 			  'and-let* 'string-case 'hash-table->alist 'concatenate
-			  'union '2^n? 'lognor 'ldb 'clamp 
-			  'sequence->string 
+			  ;'union -- heap overflow if cyclic arg
+			  '2^n? 'lognor 'ldb 'clamp 
+			  ;'sequence->string ;-- either this or rootlet but not both (endless printout)
 			  ;'*s7*->list ; reverse! etc 
 			  'log-n-of ; stack grows if n < 0?
-			  'pp
-
+			  ;'pp
 			  'kar '_dilambda_ '_vals_
 			  'free1 'free2 'free3
-
-			  'tree-cyclic?
 			  ))
 	 
-      (args (vector "-123" "1234" "-3/4" "-1" "(expt 2 32)" "4294967297" "1001" "10001" "(+ a 1)" "(- a 1)" "(logand (ash 1 b) a)"
+      (args (vector "-123" "1234" "-3/4" "-1" "(expt 2 32)" "4294967297" "1001" "10001" ;;"(+ a 1)" "(- a 1)" "(logand (ash 1 b) a)"
+		    "(ash 1 31)" "(+ (ash 1 31) 1)" "(- (ash 1 32) 1)"
 		    "(make-block 2)" "(block 1.0 2.0 3.0)" "(block)"
+		    "(make-simple-block 3)"
 		    "\"ho\"" ":ho" "'ho" "':go" "(list 1)" "(list 1 2)" "(cons 1 2)" "'()" "(list (list 1 2))" "(list (list 1))" "(list ())" "=>" 
 		    "#f" "#t" "()" "#()" "\"\"" "'#()" ":readable" ":rest" ":allow-other-keys" ":a" ;"__func__"
 		    "1/0+i" "0+0/0i" "0+1/0i" "1+0/0i" "0/0+0/0i" "0/0+i" 
-		    "cons" "''2" "\"ra\"" "gad1.data"
+		    "cons" "''2" "\"ra\"" 
 		    "(make-hook)" "(make-hook '__x__)"
 		    "1+i" "0+i" "(ash 1 43)" 
 		    "(integer->char 255)" "(string (integer->char 255))" "(string #\\null)" "(byte-vector 0)"
@@ -621,21 +553,26 @@
 		    "(string #\\c #\\null #\\b)" "#2d((100 200) (3 4))" "#r(0 1)" "#i2d((101 201) (3 4))" "#r2d((.1 .2) (.3 .4))" "#i1d(15 25)"
 		    "(values 1 2)" "(values)" "(values #\\c 3 1.2)" "(values \"ho\")"
 		    "`(x)" "`(+ x 1)" "`(x 1)" "`((x))" "`((+ x 1))" "`(((+ x 1)))" "`((set! x (+ x 1)) (* x 2))" "`((x 1))" "`(((x 1))) "
-		    "`(x . 1)" "`((x . 1))" "`(1)" "`((1))" "`((1) . x)" "'(- 1)" "(+ i 1)"
+		    "`(x . 1)" "`((x . 1))" "`(1)" "`((1))" "`((1) . x)" ;; "'(- 1)" 
+		    "(+ i 1)"
 		    ;;"'((X . 1) . 2)" "'((x 1) . 2)" "'((x 1) (y . 2))" "'((x 1) y . 2)" "'((x 1) (y) . 2)" "'((x 1 . 2) . 3)" "'((x 1) 2)" "'(((x 1) 2) 3)" 
 		    "'(())" "'((()))" "(random-state 1234)" 
 		    "(c-pointer 0 'integer?)" "(c-pointer -1)" "(c-pointer 1234)"
-		    "(inlet 'integer? (lambda (f) #f))" "(inlet 'a 1)" "(openlet (inlet 'abs (lambda (x) (- x))))" 
+		    "(inlet 'integer? (lambda (f) #f))" "(inlet 'a 1)" ;;"(openlet (inlet 'abs (lambda (x) (- x))))" 
 		    "'(15 26 . 36)" 
 		    " . "
 		    "((i 0 (+ i 1)))" "(null? i)" 
 		    "(= i 2)" "(zero? i)" "((null? i) i)" "(#t ())" 
-		    "(x => y)" "((0 1) ())" "(- i 1)" "(if x y)" "(or x y)"
+		    ;;"(x => y)" "((0 1) ())" "(- i 1)" "(if x y)" "(or x y)"
 		    ;;"(f x) i" "x y z" "1 2"
 		    "`(+ ,a ,@b)" "`(+ ,a ,b)" "`(+ ,a ,b ,@c)" "`(+ ,a b ,@c ',d)"
 		    "_definee_" "(_definee_ __var__)" "(_definee_ x)" 
 		    "(hash-table* 'a 1)" "(hash-table)" 
-		    "(make-iterator (list 11 22 33))" "(make-iterator (vector 1 2 3))" "(make-iterator (string #\\1))" "(make-iterator x)" 
+		    "(make-iterator (list 11 22 33))" "(make-iterator (int-vector 1 2 3))" "(make-iterator (string #\\1))" "(make-iterator x)" 
+		    "(make-iterator (hash-table* 'a 1 'b 2))" "(make-iterator (block 1 2 3))"
+		    "(make-iterator (let ((lst '((a . 1) (b . 2) (c . 2))) 
+                                       (+iterator+ #t)) (lambda () (if (pair? lst) (let ((res (list (caar lst) (cdar lst)))) (set! lst (cdr lst)) res) #<eof>))))"
+
 		    "#<eof>" "#<undefined>" "#<unspecified>"
 		    "#o123" "#b101" "#\\newline" "#\\alarm" "#\\delete" "#_cons" "#x123.123" "#\\x65" ;"_1234_" "kar"
 		    
@@ -662,13 +599,6 @@
 		    "__var2__"
 		    ;; "\"~S~%\"" "\"~A~D~X\"" "\"~{~A~^~}~%\"" "\"~NC~&\"" -- creates files by these names!
 		    "ims" "imbv" "imv" "imiv" "imfv" "imi" "imb" "imh" ;;"imp"--many ways to cloober this
-		    ;"(immutable! (string #\\a #\\b #\\c))" "(immutable! (byte-vector 0 1 2))" 
-		    ;"(immutable! (vector 0 1 2))" "(immutable! (int-vector 0 1 2))" "(immutable! (float-vector 0 1 2))" 
-		    ;"(immutable! (inlet 'a 1 'b 2))" 
-		    ;"(immutable! (block 0.0 1.0 2.0))" 
-		    ;"(immutable! (hash-table* 'a 1 'b 2))"
-		    ;"(immutable! (cons 0 (immutable! (cons 1 (immutable! (cons 2 ()))))))"
-		    ;"(immutable! 'x)"
 
 		    "(mock-number 0)" "(mock-number 1-i)" "(mock-number 4/3)" "(mock-number 2.0)"
 		    "(mock-string #\\h #\\o #\\h #\\o)"
@@ -678,11 +608,6 @@
 		    "(mock-vector 1 2 3 4)"
 		    "(mock-hash-table* 'b 2)"
 
-		    ;;"(make-list 16 0)" "(make-vector 16 0)" "(make-int-vector 16 0)" "(make-float-vector 16 0)" "(make-byte-vector 16 0)"
-		    ;;"(make-string 16 #\\0)"
-		    ;;"(let ((hash (make-hash-table))) (do ((i 0 (+ i 1))) ((= i 16) hash) (hash-table-set! hash i 0)))"
-		    ;;"(let ((lt (inlet))) (do ((i 0 (+ i 1))) ((= i 16) lt) (varlet lt (symbol \"i\" (number->string i)) 0)))"
-		    
 		    ;;" #| a comment |# "
 		    "(make-shared-vector (vector 0 1 2 3 4) 3)" "(substring \"0123\" 2)"
 		    "(vector-dimensions (block))" 
@@ -695,7 +620,7 @@
 		    "#xfeedback" "#_asdf"
 		    ;"quote" "'"
 		    "if" "begin" "cond" "case" "when" "unless" "letrec" "letrec*" "or" "and" "let-temporarily"
-		    "lambda*" "lambda"
+		    ;;"lambda*" "lambda" ;-- cyclic body etc
 		    ;;"let" "let*" "do" "set!" "with-let" ;"define" "define*" "define-macro" "define-macro*" "define-bacro" "define-bacro*"
 
 		    "(begin (string? (stacktrace)))"
@@ -706,7 +631,17 @@
 		    "(let ((<1> #f) (<2> (vector #f))) (set! <1> (make-iterator <2>)) (set! (<2> 0) <1>) <1>)"
 		    "(let ((<1> (list 1 #f))) (set! (<1> 1) (let ((<L> (list #f 3))) (set-car! <L> <1>) <L>)) <1>)"
 
-		    #f #f
+		    "(begin (list? (*s7* 'catches)))"
+		    "(begin (list? (*s7* 'exits)))"
+		    "(begin (integer? (*s7* 'stack-top)))"
+		    ;"(begin (string? (object->string (*s7* 'stack))))"
+		    ;"(begin (string? (object->string (*s7* 'stack) :readable)))"
+		    "(begin (string? (object->string (*s7* 'catches))))"
+		    "(begin (string? (object->string (*s7* 'exits))))"
+		    "(begin (vector? (*s7* 'gc-protected-objects)))"
+		    "(begin (list? (*s7* 'stacktrace-defaults)))"
+
+		    #f #f #f #f ;#f #f #f #f #f #f 
 		    ))
 
       (codes (vector 
@@ -747,7 +682,7 @@
 	      (list "(do ((i 0 (+ i 1))) ((= i 1)) (do ((j 0 (+ j 1))) ((= j 1)) "
 		    "(do ((i 0 (+ i 1))) ((= i 1)) (let ((j 0)) ")
 	      (list "(or (_cop1_ " "(and (_cop2_ ")
-	      (list "(values (_rd1_ " "(append (_rd2_ ")
+	      ;;(list "(values (_rd1_ " "(append (_rd2_ ")
 	      ))
       
       (chars (vector #\( #\( #\) #\space))) ; #\/ #\# #\, #\` #\@ #\. #\:))  ; #\\ #\> #\space))
@@ -873,8 +808,8 @@
 	       (eq? (type-of val1) (type-of val3))
 	       (eq? (type-of val1) (type-of val4)))
 	  (cond ((or (openlet? val1)
-		      (string-position "(set!" str1)
-		      (string-position "gensym" str1)))
+		     (string-position "(set!" str1)
+		     (string-position "gensym" str1)))
 
 		((symbol? val1)
 		 (if (gensym? val1)
@@ -960,9 +895,10 @@
     (define (eval-it str) ;(format #t "~A~%" str)
       ;(format *stderr* "~S~%" str)
       (set! __var__ __old_var__)
+      (set! estr str)
       (catch #t 
 	(lambda ()
-	  (car (list (eval-string str))))
+	  (car (list (eval-string str)))) ; wrap in (with-let (unlet)...) to avoid changes?
 	(lambda (type info)
 	  (set! error-type type)
 	  (set! error-info info)
@@ -973,8 +909,7 @@
 	  (if (eq? type 'stack-too-big)
 	      (format *stderr* "stack overflow from ~S~%" str))
 	  (when (eq? type 'heap-too-big)
-	    (format *stderr* "heap overflow from ~S~%" str)
-	    (abort))
+	    (format *stderr* "heap overflow from ~S~%" str))
           'error)))
 
     (define (try-both str)
@@ -989,7 +924,7 @@
 	(lambda arg 'error))
 
       (set! last-error-type #f)
-      (let* ((outer (codes (random codes-len)))	     
+      (let* ((outer (codes (random codes-len)))
 	     (str1 (string-append "(let ((x #f) (i 0)) " (car outer) str ")))"))
 	     (str2 (string-append "(let () (define (func) " str1 ") (define (hi) (func)) (hi))"))
 	     (str3 (string-append "(let ((x #f) (i 0)) " (cadr outer) str ")))"))
@@ -1004,14 +939,15 @@
 	    (format *stderr* "current-output-port is ~S from ~S and ~S~%" (current-output-port) str1 str2)
 	    (set! (current-output-port) #f))
 
-	  (unless (eq? (current-input-port) startup-input-port)
-	    (format *stderr* "current-input-port is ~S from ~S and ~S~%" (current-input-port) str1 str2)
-	    (set! (current-input-port) startup-input-port))
-
 	  ;; if val1 examined, remember: (if (and (let? val1) (openlet? val1)); (not (eq? val1 (rootlet)))) (coverlet val1)) ; might be open and have a length func
 	  ))
 
 #|
+      (let ((nstr (make-expr (+ 1 (random 4))))
+	    (pstr (make-expr (+ 1 (random 4)))))
+	(let ((str1 (string-append "(let ((x (car (list " nstr ")))) (do ((i 0 (+ i 1))) ((= i 2) x) " ostr " (set! x (car (list " pstr ")))))")))
+	  (eval-it str1)))
+
       (catch #t
 	(lambda ()
 	  (let ((val1 (car (list (eval-string str)))))
@@ -1094,13 +1030,12 @@
 	  (set! n (+ n 1))
 	  (if (= n 4) (set! n 0))
 	  (format *stderr* "~A" (vector-ref dots n)))
-
+	
 	(try-both (make-expr (+ 1 (random 6)))) ; min 1 here not 0
 	(set! __var__ ((lambda args (car args)) (catch #t (lambda () (eval-string (get-arg))) (lambda () #f))))
 	(if (iterator? __var__) (set! __var__ #f))
 	(set! __old_var__ __var__)
+	;(set! - #_-)
 	))
 
     (test-it)))
-
-
