@@ -101,7 +101,7 @@ static void mark_dax(void *val)
   if (o) s7_mark_c_object(o->data);
 }
 
-static int dax_type_tag = 0;
+static s7_int dax_type_tag = 0;
 
 static s7_pointer make_dax(s7_scheme *sc, s7_pointer args)
 {
@@ -260,7 +260,7 @@ typedef struct {
   double *data;
 } g_block;    
 
-static int g_block_type = 0;
+static s7_int g_block_type = 0;
 static s7_pointer g_block_methods;
 
 static s7_pointer g_make_block(s7_scheme *sc, s7_pointer args)
@@ -386,14 +386,80 @@ static bool symbol_func(const char *symbol_name, void *data)
   return(false);
 }
 
+static bool symbol_func_1(const char *symbol_name, s7_pointer value, void *data)
+{
+  return(false);
+}
+
+static s7_scheme *cur_sc;
+static s7_pointer ap_1(s7_pointer a1) 
+{
+  return(s7_make_integer(cur_sc, s7_integer(a1)));
+}
+
+static s7_pointer ap_2(s7_pointer a1, s7_pointer a2) 
+{
+  return(s7_make_integer(cur_sc, s7_integer(a1) + s7_integer(a2)));
+}
+
+static s7_pointer ap_3(s7_pointer a1, s7_pointer a2, s7_pointer a3) 
+{
+  return(s7_make_integer(cur_sc, s7_integer(a1) + s7_integer(a2) + s7_integer(a3)));
+}
+
+static s7_pointer ap_4(s7_pointer a1, s7_pointer a2, s7_pointer a3, s7_pointer a4) 
+{
+  return(s7_make_integer(cur_sc, s7_integer(a1) + s7_integer(a2) + s7_integer(a3) + s7_integer(a4)));
+}
+
+static s7_pointer ap_5(s7_pointer a1, s7_pointer a2, s7_pointer a3, s7_pointer a4, s7_pointer a5) 
+{
+  return(s7_make_integer(cur_sc, s7_integer(a1) + s7_integer(a2) + s7_integer(a3) + s7_integer(a4) + s7_integer(a5)));
+}
+
+static s7_pointer ap_6(s7_pointer a1, s7_pointer a2, s7_pointer a3, s7_pointer a4, s7_pointer a5, s7_pointer a6) 
+{
+  return(s7_make_integer(cur_sc, s7_integer(a1) + s7_integer(a2) + s7_integer(a3) + s7_integer(a4) + s7_integer(a5) + s7_integer(a6)));
+}
+
+static s7_pointer ap_7(s7_pointer a1, s7_pointer a2, s7_pointer a3, s7_pointer a4, s7_pointer a5, s7_pointer a6, s7_pointer a7) 
+{
+  return(s7_make_integer(cur_sc, s7_integer(a1) + s7_integer(a2) + s7_integer(a3) + s7_integer(a4) + s7_integer(a5) + s7_integer(a6) + s7_integer(a7)));
+}
+
+static s7_pointer ap_8(s7_pointer a1, s7_pointer a2, s7_pointer a3, s7_pointer a4, s7_pointer a5, s7_pointer a6, s7_pointer a7, s7_pointer a8) 
+{
+  return(s7_make_integer(cur_sc, s7_integer(a1) + s7_integer(a2) + s7_integer(a3) + s7_integer(a4) + s7_integer(a5) + s7_integer(a6) + s7_integer(a7) + s7_integer(a8)));
+}
+
+static s7_pointer ap_9(s7_pointer a1, s7_pointer a2, s7_pointer a3, s7_pointer a4, s7_pointer a5, s7_pointer a6, s7_pointer a7, s7_pointer a8, s7_pointer a9) 
+{
+  return(s7_make_integer(cur_sc, s7_integer(a1) + s7_integer(a2) + s7_integer(a3) + s7_integer(a4) + s7_integer(a5) + s7_integer(a6) + s7_integer(a7) + s7_integer(a8) + s7_integer(a9)));
+}
+
+static s7_pointer int_list(s7_scheme *sc, s7_int len)
+{
+  s7_int i, gc_loc;
+  s7_pointer result;
+  s7_eval_c_string(sc, "(set! (*s7* 'safety) 1)");
+  result = s7_list(sc, 1, s7_nil(sc));
+  s7_eval_c_string(sc, "(set! (*s7* 'safety) 0)");
+  gc_loc = s7_gc_protect(sc, result);
+  for (i = 1; i <= len; i++)
+    s7_set_car(result, s7_cons(sc, s7_make_integer(sc, i), s7_car(result)));
+  s7_gc_unprotect_at(sc, gc_loc);
+  return(s7_reverse(sc, s7_car(result)));
+}
+
 int main(int argc, char **argv)
 {
   s7_scheme *sc;
   s7_pointer p, p1;
-  int i, gc_loc;
+  s7_int i, gc_loc;
   char *s1, *s2;
   
-  sc = s7_init(); 
+  sc = s7_init();
+  cur_sc = sc;
   
   /* try each straight (no errors) case */
 
@@ -446,7 +512,22 @@ int main(int argc, char **argv)
 
   if (!s7_is_valid(sc, s7_t(sc)))
     {fprintf(stderr, "%d: %s is not valid?\n", __LINE__, s1 = TO_STR(s7_t(sc))); free(s1);}
-
+  {
+    typedef struct fake_cell {
+      union {
+	uint64_t flag;
+	uint8_t type_field;
+      } tf;
+      int64_t hloc, i1, i2, i3;
+    } fake_cell;
+    fake_cell *x;
+    x = calloc(1, sizeof(fake_cell));
+    x->tf.flag = 53 + (1 << 11);
+    if (s7_is_valid(sc, (s7_pointer)x))
+      fprintf(stderr, "fake_cell is ok?\n");
+    if (!s7_is_provided(sc, "debugging"))
+      s7_object_to_c_string(sc, (s7_pointer)x);
+  }
   if (s7_is_c_pointer(s7_t(sc)))
     {fprintf(stderr, "%d: %s is a raw c pointer?\n", __LINE__, s1 = TO_STR(s7_t(sc))); free(s1);}
 
@@ -457,7 +538,7 @@ int main(int argc, char **argv)
 
   i = (*((int *)s7_c_pointer(p)));
   if (i != 32)
-    fprintf(stderr, "%d: 32 -> %d via raw c pointer?\n", __LINE__, i);
+    fprintf(stderr, "%d: 32 -> %" PRId64 " via raw c pointer?\n", __LINE__, i);
 
   s7_provide(sc, "ffitest");
   if (!s7_is_provided(sc, "ffitest"))
@@ -466,7 +547,7 @@ int main(int argc, char **argv)
   p = s7_cons(sc, s7_f(sc), s7_t(sc));
   gc_loc = s7_gc_protect(sc, p);
   if (p != s7_gc_protected_at(sc, gc_loc))
-    {fprintf(stderr, "%d: %s is not gc protected at %d: %s?\n", __LINE__, s1 = TO_STR(p), gc_loc, s2 = TO_STR(s7_gc_protected_at(sc, gc_loc))); free(s1); free(s2);}
+    {fprintf(stderr, "%d: %s is not gc protected at %" PRId64 ": %s?\n", __LINE__, s1 = TO_STR(p), gc_loc, s2 = TO_STR(s7_gc_protected_at(sc, gc_loc))); free(s1); free(s2);}
   
   if (s7_car(p) != s7_f(sc))
     {fprintf(stderr, "%d: (car %s) is not #f?\n", __LINE__, s1 = TO_STR(p)); free(s1);}
@@ -520,6 +601,8 @@ int main(int argc, char **argv)
 
   if (s7_number_to_integer(sc, p) != 123)
     {fprintf(stderr, "%d: s7_number_to_integer %s is not 123?\n", __LINE__, s1 = TO_STR(p)); free(s1);}
+  if (s7_number_to_integer_with_caller(sc, p, "ffitest") != 123)
+    {fprintf(stderr, "%d: s7_number_to_integer_with_caller %s is not 123?\n", __LINE__, s1 = TO_STR(p)); free(s1);}
 
   s7_gc_unprotect_at(sc, gc_loc);
   
@@ -592,7 +675,10 @@ int main(int argc, char **argv)
     {fprintf(stderr, "%d: s7_number_to_real %s is not 1.5?\n", __LINE__, s1 = TO_STR(p)); free(s1);}
 
   s7_gc_unprotect_at(sc, gc_loc);
-  
+
+  p = s7_make_mutable_real(sc, 1.5);
+  if (!s7_is_real(p))
+    {fprintf(stderr, "%d: %s is not real?\n", __LINE__, s1 = TO_STR(p)); free(s1);}
 
   p = s7_make_complex(sc, 1.0, 1.0);
   gc_loc = s7_gc_protect(sc, p);
@@ -618,6 +704,26 @@ int main(int argc, char **argv)
   if (s7_real_part(p) != 1.0)
     {fprintf(stderr, "%d: (real-part %s) is not 1.0?\n", __LINE__, s1 = TO_STR(p)); free(s1);}
 
+  if (s7_integer(s7_apply_1(sc, int_list(sc, 1), ap_1)) != 1) fprintf(stderr, "apply_1 != 1\n");
+  if (s7_integer(s7_apply_2(sc, int_list(sc, 2), ap_2)) != 3) fprintf(stderr, "apply_2 != 3\n");
+  if (s7_integer(s7_apply_3(sc, int_list(sc, 3), ap_3)) != 6) fprintf(stderr, "apply_3 != 6\n");
+  if (s7_integer(s7_apply_4(sc, int_list(sc, 4), ap_4)) != 10) fprintf(stderr, "apply_4 != 10\n");
+  if (s7_integer(s7_apply_5(sc, int_list(sc, 5), ap_5)) != 15) fprintf(stderr, "apply_5 != 15\n");
+  if (s7_integer(s7_apply_6(sc, int_list(sc, 6), ap_6)) != 21) fprintf(stderr, "apply_6 != 21\n");
+  if (s7_integer(s7_apply_7(sc, int_list(sc, 7), ap_7)) != 28) fprintf(stderr, "apply_7 != 28\n");
+  if (s7_integer(s7_apply_8(sc, int_list(sc, 8), ap_8)) != 36) fprintf(stderr, "apply_8 != 36\n");
+  if (s7_integer(s7_apply_9(sc, int_list(sc, 9), ap_9)) != 45) fprintf(stderr, "apply_9 != 45\n");
+
+  if (s7_integer(s7_apply_n_1(sc, int_list(sc, 1), ap_1)) != 1) fprintf(stderr, "apply_1 != 1\n");
+  if (s7_integer(s7_apply_n_2(sc, int_list(sc, 2), ap_2)) != 3) fprintf(stderr, "apply_2 != 3\n");
+  if (s7_integer(s7_apply_n_3(sc, int_list(sc, 3), ap_3)) != 6) fprintf(stderr, "apply_3 != 6\n");
+  if (s7_integer(s7_apply_n_4(sc, int_list(sc, 4), ap_4)) != 10) fprintf(stderr, "apply_4 != 10\n");
+  if (s7_integer(s7_apply_n_5(sc, int_list(sc, 5), ap_5)) != 15) fprintf(stderr, "apply_5 != 15\n");
+  if (s7_integer(s7_apply_n_6(sc, int_list(sc, 6), ap_6)) != 21) fprintf(stderr, "apply_6 != 21\n");
+  if (s7_integer(s7_apply_n_7(sc, int_list(sc, 7), ap_7)) != 28) fprintf(stderr, "apply_7 != 28\n");
+  if (s7_integer(s7_apply_n_8(sc, int_list(sc, 8), ap_8)) != 36) fprintf(stderr, "apply_8 != 36\n");
+  if (s7_integer(s7_apply_n_9(sc, int_list(sc, 9), ap_9)) != 45) fprintf(stderr, "apply_9 != 45\n");
+
   if (s7_imag_part(p) != 1.0)
     {fprintf(stderr, "%d: (imag-part %s) is not 1.0?\n", __LINE__, s1 = TO_STR(p)); free(s1);}
 
@@ -631,6 +737,11 @@ int main(int argc, char **argv)
     fprintf(stderr, "s7_immutable failed?\n");
   s7_gc_unprotect(sc, p);
 
+  p = s7_signature(sc, s7_name_to_value(sc, "abs"));
+  if (!s7_is_pair(p))
+    {fprintf(stderr, "%d: %s is not a pair?\n", __LINE__, s1 = TO_STR(p)); free(s1);}
+  
+#if 0
   {
     int64_t size;
     size = s7_heap_size(sc);
@@ -639,6 +750,7 @@ int main(int argc, char **argv)
     if (size < 0) fprintf(stderr, "gc_freed: %" PRId64 "?\n", size);
     s7_gc_stats(sc, false);
   }
+#endif
 
   {
     s7_pointer p;
@@ -655,6 +767,27 @@ int main(int argc, char **argv)
     fprintf(stderr, "s7_c_pointer_type is not ()\n");
   if (!s7_is_int_vector(s7_make_int_vector(sc, 3, 1, NULL)))
     fprintf(stderr, "s7_make_int_vector did not make an int-vector\n");
+  if (s7_is_float_vector(s7_make_int_vector(sc, 3, 1, NULL)))
+    fprintf(stderr, "s7_make_int_vector made a float-vector?\n");
+  
+  {
+    s7_int* dims;
+    s7_pointer p;
+    dims = (s7_int *)malloc(2 * sizeof(s7_int));
+    dims[0] = 2;
+    dims[1] = 3;
+    p = s7_make_int_vector(sc, 6, 2, dims);
+    if (s7_vector_rank(p) != 2) fprintf(stderr, "int vector rank not 2?\n");
+    p = s7_make_float_vector(sc, 6, 2, dims);
+    if (s7_vector_rank(p) != 2) fprintf(stderr, "float vector rank not 2?\n");
+    free(dims); /* ?? */
+  }
+
+  {
+    s7_int len;
+    len = s7_print_length(sc);
+    s7_set_print_length(sc, len);
+  }
 
   p = s7_rationalize(sc, 1.5, 1e-12);
   gc_loc = s7_gc_protect(sc, p);
@@ -664,6 +797,7 @@ int main(int argc, char **argv)
   free(s1);
   s7_gc_unprotect_at(sc, gc_loc);
   
+  s7_set_default_random_state(sc, 1234, 5678);
   s7_random(sc, NULL);
   s7_stacktrace(sc);
   if (s7_list(sc, 0) != s7_nil(sc))
@@ -674,6 +808,8 @@ int main(int argc, char **argv)
 
   if (!s7_is_vector(p))
     {fprintf(stderr, "%d: %s is not a vector?\n", __LINE__, s1 = TO_STR(p)); free(s1);}
+  if (s7_type_of(p) != s7_make_symbol(sc, "vector?"))
+    fprintf(stderr, "type-of(vector) confused?\n");
 
   if (s7_vector_rank(p) != 1)
     {fprintf(stderr, "%d: (dimensions %s) is not 1?\n", __LINE__, s1 = TO_STR(p)); free(s1);}
@@ -726,6 +862,8 @@ int main(int argc, char **argv)
 
   p = s7_list(sc, 3, TO_S7_INT(1), TO_S7_INT(2), TO_S7_INT(3));
   gc_loc = s7_gc_protect(sc, p);
+  if (s7_tree_memq(sc, s7_make_symbol(sc, "oops"), p))
+    fprintf(stderr, "'oops is in the list?\n");
 
   if (!s7_is_list(sc, p))
     {fprintf(stderr, "%d: %s is not a list?\n", __LINE__, s1 = TO_STR(p)); free(s1);}
@@ -930,6 +1068,7 @@ int main(int argc, char **argv)
 #endif
 
   s7_for_each_symbol_name(sc, symbol_func, NULL);
+  s7_for_each_symbol(sc, symbol_func_1, NULL);
   s7_symbol_name(s7_make_symbol(sc, "a_symbol"));
 
   p = s7_make_hash_table(sc, 255);
@@ -949,6 +1088,9 @@ int main(int argc, char **argv)
   p = s7_current_input_port(sc);
   if (!s7_is_input_port(sc, p))
     {fprintf(stderr, "%d: %s is not an input port?\n", __LINE__, s1 = TO_STR(p)); free(s1);}
+  s7_port_line_number(p);
+  s7_add_to_history(sc, s7_nil(sc));
+  s7_history(sc);
 
   p = s7_current_output_port(sc);
   if (!s7_is_output_port(sc, p))
@@ -1244,11 +1386,11 @@ int main(int argc, char **argv)
       {
 	/* (define loaded_var 321) hopefully */
 	gc_loc = s7_gc_protect(sc, port);
-	s7_write_char(sc, (int)'(', port);
+	s7_write_char(sc, s7_make_character(sc, (uint8_t)'('), port);
 	s7_write(sc, s7_make_symbol(sc, "define"), port);
-	s7_write_char(sc, (int)' ', port);
+	s7_write_char(sc, s7_make_character(sc, (uint8_t)' '), port);
 	s7_display(sc, s7_make_symbol(sc, "loaded_var"), port);
-	s7_write_char(sc, (int)' ', port);
+	s7_write_char(sc, s7_make_character(sc, (uint8_t)' '), port);
 	s7_format(sc, s7_list(sc, 3, port, s7_make_string(sc, "~A)"), TO_S7_INT(321)));
 	s7_newline(sc, port);
 	s7_flush_output_port(sc, port);
@@ -1260,7 +1402,6 @@ int main(int argc, char **argv)
 	  {fprintf(stderr, "%d: load unhappy?\n", __LINE__);}
 	else
 	  {
-	    int c;
 	    if (s7_integer(p = s7_name_to_value(sc, "loaded_var")) != 321)
 	      {fprintf(stderr, "%d: %s is not 321?\n", __LINE__, s1 = TO_STR(p)); free(s1);}
 
@@ -1269,13 +1410,14 @@ int main(int argc, char **argv)
 	      {fprintf(stderr, "%d: %s is not an input port?\n", __LINE__, s1 = TO_STR(port)); free(s1);}
 	    else
 	      {
+		uint8_t c;
 		gc_loc = s7_gc_protect(sc, port);
-		c = s7_peek_char(sc, port);
+		c = s7_character(s7_peek_char(sc, port));
 		if (c != (int)'(')
 		  {fprintf(stderr, "%d: peek-char sees %c?\n", __LINE__, (unsigned char)c);}
 		
-		c = s7_read_char(sc, port);
-		if (c != (int)'(')
+		c = s7_character(s7_read_char(sc, port));
+		if (c != (uint8_t)'(')
 		  {fprintf(stderr, "%d: read-char sees %c?\n", __LINE__, (unsigned char)c);}
 		
 		s7_close_input_port(sc, port);
@@ -1373,8 +1515,8 @@ int main(int argc, char **argv)
     s7_display(sc, s7_make_character(sc, '3'), s7_current_output_port(sc));
     if (last_c != '3')
       {fprintf(stderr, "%d: last_c: %c, c: %c\n", __LINE__, last_c, '3');}
-    last_c = s7_read_char(sc, p1);
-    if (last_c != '0')
+    last_c = s7_character(s7_read_char(sc, p1));
+    if (last_c != '0') 
       {fprintf(stderr, "%d: last_c: %c\n", __LINE__, last_c);}
     s7_set_current_output_port(sc, p);
     s7_gc_unprotect_at(sc, gc_loc);
@@ -1477,6 +1619,10 @@ int main(int argc, char **argv)
     s3 = s7_help(sc, p1);
     if (strcmp(s3, "(abs x) returns the absolute value of the real number x") != 0)
       {fprintf(stderr, "%d: (help abs) = %s?\n", __LINE__, s3);}
+
+    s3 = s7_documentation(sc, s7_make_symbol(sc, "abs"));
+    if (strcmp(s3, "(abs x) returns the absolute value of the real number x") != 0)
+      {fprintf(stderr, "%d: (documentation 'abs) = %s?\n", __LINE__, s3);}    
   }
 
   p = s7_eval_c_string(sc, "(lambda (a b . c) (+ a b (apply * c)))");
@@ -1500,6 +1646,13 @@ int main(int argc, char **argv)
     {fprintf(stderr, "%d: s7_closure_let is %s?\n", __LINE__, s1);}
   free(s1);
   
+  if (s7_closure_body(sc, s7_name_to_value(sc, "abs")) != s7_nil(sc))
+    fprintf(stderr, "closure_body(abs) is not nil?\n");
+  if (s7_closure_args(sc, s7_name_to_value(sc, "abs"))  != s7_nil(sc))
+    fprintf(stderr, "closure_args(abs) is not nil?\n");
+  if (s7_closure_let(sc, s7_name_to_value(sc, "abs"))  != s7_nil(sc))
+    fprintf(stderr, "closure_let(abs) is not nil?\n");
+  
   if (!s7_is_aritable(sc, p, 2))
     {fprintf(stderr, "%d: aritable? lambda 2 = #f?\n", __LINE__);}
   if (s7_is_aritable(sc, p, 1))
@@ -1557,9 +1710,9 @@ int main(int argc, char **argv)
       {fprintf(stderr, "%d: g_block %s is not a c_object?\n", __LINE__, s1 = TO_STR(gp)); free(s1);}
     g = (g_block *)s7_c_object_value(gp);
     if (s7_c_object_type(gp) != g_block_type)
-      {fprintf(stderr, "%d: g_block types: %d %d\n", __LINE__, g_block_type, s7_c_object_type(gp));}
+      {fprintf(stderr, "%d: g_block types: %" PRId64 " %" PRId64 "\n", __LINE__, g_block_type, s7_c_object_type(gp));}
     if (s7_c_object_value_checked(gp, g_block_type) != g)
-      {fprintf(stderr, "%d: checked g_block types: %d %d\n", __LINE__, g_block_type, s7_c_object_type(gp));}
+      {fprintf(stderr, "%d: checked g_block types: %" PRId64 " %" PRId64 "\n", __LINE__, g_block_type, s7_c_object_type(gp));}
 
     s7_gc_unprotect_at(sc, gc_loc);
   }
